@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: acontainer.h,v 1.2 2004/02/01 21:33:21 ralf Exp $ */
+/* $Id: acontainer.h,v 1.3 2004/03/18 06:55:57 ralf Exp $ */
 
 #ifndef ACONTAINER_H
 #define ACONTAINER_H
@@ -30,6 +30,8 @@ class AContainer
 public:
   AContainer( class AWindow *twin, int txelems = 1, int tyelems = 1 );
   virtual ~AContainer();
+  AContainer( const AContainer &other );
+  AContainer &operator=( const AContainer &other );
 
   enum { ACONT_NONE = 0,
 	 ACONT_MAXW = 1,
@@ -84,6 +86,9 @@ public:
   class AContElem {
   public:
     AContElem();
+    AContElem( const AContElem &other );
+    AContElem &operator=( const AContElem &other );
+
     class GUIElement *guielem() const;
     AContainer *cont() const;
     class AWindow *win() const;
