@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: acontainerbb.h,v 1.1 2004/02/01 21:32:46 ralf Exp $ */
+/* $Id: acontainerbb.h,v 1.2 2004/03/18 06:56:48 ralf Exp $ */
 
 #ifndef ACONTAINERBB_H
 #define ACONTAINERBB_H
@@ -31,6 +31,8 @@ class AContainerBB : public AContainer
 public:
   AContainerBB( class AWindow *twin, int txelems = 1, int tyelems = 1 );
   ~AContainerBB();
+  AContainerBB( const AContainerBB &other );
+  AContainerBB &operator=( const AContainerBB &other );
   
   int rearrange( int vhmode = 0 );
   int remove( const GUIElement *v );
