@@ -1,6 +1,6 @@
 /* aguix.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001 Ralf Hoffmann.
+ * Copyright (C) 2001-2004 Ralf Hoffmann.
  * You can contact me at: ralf.hoffmann@epost.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: aguix.cc,v 1.67 2004/03/10 22:26:07 ralf Exp $ */
+/* $Id: aguix.cc,v 1.70 2004/07/18 19:13:28 ralf Exp $ */
 
 #include "aguix.h"
 #include "awindow.h"
@@ -625,6 +625,13 @@ Message *AGUIX::wait4mess( int mode )
       newmsg->height = LastEvent.xexpose.height;
       break;
     case ConfigureNotify:
+      // first try to find further configure notifies for
+      // this window to improve handling of many resizes due to
+      // solid resize used by many WMs
+      while ( XCheckTypedWindowEvent( dsp,
+				      LastEvent.xconfigure.window,
+				      ConfigureNotify,
+				      &LastEvent ) == True );
       newmsg->window=LastEvent.xconfigure.window;
       newmsg->mousex=LastEvent.xconfigure.x;
       newmsg->mousey=LastEvent.xconfigure.y;
@@ -1475,7 +1482,7 @@ bool AGUIX::isDoubleClick(struct timeval *t1,struct timeval *t2) const
   int dt=0;
   int s,us;
 
-  s=abs(t1->tv_sec-t2->tv_sec);
+  s = abs( (int)( t1->tv_sec - t2->tv_sec ) );
   if ( s > 2 ) return false;
   us=t1->tv_usec-t2->tv_usec;
   if(us<0) {
