@@ -1,6 +1,6 @@
 /* aguix.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001 Ralf Hoffmann.
+ * Copyright (C) 2001-2004 Ralf Hoffmann.
  * You can contact me at: ralf.hoffmann@epost.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: aguix.h,v 1.45 2004/03/10 22:26:15 ralf Exp $ */
+/* $Id: aguix.h,v 1.46 2004/03/18 06:57:28 ralf Exp $ */
 
 #ifndef AGUIX_H
 #define AGUIX_H
@@ -47,6 +47,9 @@ class AGUIX {
 public:
   AGUIX();
   ~AGUIX();
+  AGUIX( const AGUIX &other );
+  AGUIX &operator=( const AGUIX &other );
+
   int initX( int argc, char **argv, const char *classname );
   int checkX();
   void closeX();
@@ -240,6 +243,9 @@ class AGUIXFont
 public:
   AGUIXFont(AGUIX*);
   ~AGUIXFont();
+  AGUIXFont( const AGUIXFont &other );
+  AGUIXFont &operator=( const AGUIXFont &other );
+
   int setFont( const char* );
   void removeFont();
   GC getGC() const;
