@@ -1,6 +1,6 @@
 /* awindow.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001 Ralf Hoffmann.
+ * Copyright (C) 2001-2004 Ralf Hoffmann.
  * You can contact me at: ralf.hoffmann@epost.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: awindow.cc,v 1.53 2004/03/10 22:26:25 ralf Exp $ */
+/* $Id: awindow.cc,v 1.56 2004/07/18 19:15:03 ralf Exp $ */
 
 #include "awindow.h"
 
@@ -50,6 +50,7 @@ AWindow::AWindow(AGUIX *parent)
   mapNr = 0;
   container = NULL;
   contAutoResize = false;
+  msgW = msgH = -1;
 }
 
 int AWindow::create(AWindow *parent,int tx,int ty,int width,int height,int tbg,const char *ttitle)
@@ -147,7 +148,9 @@ AGUIX *AWindow::getAGUIX() const
 
 void AWindow::sizeChanged(int width,int height)
 {
+#if 0
   if((width!=w)||(height!=h)) {
+#endif
     AGMessage *agmsg = AGUIX_allocAGMessage();
     agmsg->type=AG_SIZECHANGED;
     agmsg->size.window=win;
@@ -160,7 +163,9 @@ void AWindow::sizeChanged(int width,int height)
       container->resize( w, h );
       container->rearrange();
     }
+#if 0
   }
+#endif
 }
 
 void AWindow::redraw()
@@ -480,7 +485,11 @@ bool AWindow::handleMessage(XEvent *E,Message *msg)
     
     if(msg->window==win) {
       if(msg->type==ConfigureNotify) {
-	sizeChanged( msg->width, msg->height );
+        if ( ( msg->width != msgW ) || ( msg->height != msgH ) ) {
+          msgW = msg->width;
+          msgH = msg->height;
+          sizeChanged( msg->width, msg->height );
+	}
       }
     }
   }
@@ -653,14 +662,17 @@ void AWindow::resize(int nw,int nh)
       }
 
       XResizeWindow(dsp,win,nw,nh);
+#if 1
+      // it's possible to not call sizeChanged here
+      // but the size has to be stored so if one use
+      // this case, the test in sizeChanged for different size
+      // has to be removed because it would be always true in the
+      // manual resize case
       w=nw;
       h=nh;
-      AGMessage *agmsg = AGUIX_allocAGMessage();
-      agmsg->type = AG_SIZECHANGED;
-      agmsg->size.window = win;
-      agmsg->size.neww = w;
-      agmsg->size.newh = h;
-      aguix->putAGMsg( agmsg );
+#else
+      sizeChanged( nw, nh );
+#endif
     }
   }
 }
