@@ -1,6 +1,6 @@
 /* awindow.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001 Ralf Hoffmann.
+ * Copyright (C) 2001-2004 Ralf Hoffmann.
  * You can contact me at: ralf.hoffmann@epost.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: awindow.h,v 1.32 2004/03/10 22:26:31 ralf Exp $ */
+/* $Id: awindow.h,v 1.36 2004/06/14 20:50:22 ralf Exp $ */
 
 #ifndef AWINDOW_H
 #define AWINDOW_H
@@ -37,7 +37,10 @@
 class AWindow {
 public:
   AWindow(AGUIX *parent);
-  ~AWindow();
+  virtual ~AWindow();
+  AWindow( const AWindow &other );
+  AWindow &operator=( const AWindow &other );
+
   Display *getDisplay() const;
   Window getWindow() const;
   Screen *getScreen() const;
@@ -47,7 +50,7 @@ public:
   void setMaxSize(int mwidth,int mheight);
   void setMinSize(int mwidth,int mheight);
   int create(AWindow *parent,int x,int y,int width,int height,int bg,const char *title);
-  void close();
+  virtual void close();
   void show();
   void show(Window);
   void hide();
@@ -73,7 +76,7 @@ public:
   int getBG() const;
   void setBG(int bg);
   void ReactMessage(Message *msg);
-  bool handleMessage(XEvent *,Message *msg);
+  virtual bool handleMessage(XEvent *,Message *msg);
   void resizeSubWin(Window win,int w,int h);
   void moveSubWin(Window win,int x,int y);
   bool hasSubWin(Window win);
@@ -171,6 +174,7 @@ protected:
   int mapNr;
   AContainer *container;
   bool contAutoResize;
+  int msgW, msgH;
 };
 
 #endif
