@@ -1,6 +1,6 @@
 /* bevelbox.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001 Ralf Hoffmann.
+ * Copyright (C) 2001-2004 Ralf Hoffmann.
  * You can contact me at: ralf.hoffmann@epost.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: bevelbox.h,v 1.5 2004/01/22 21:18:01 ralf Exp $ */
+/* $Id: bevelbox.h,v 1.6 2004/03/18 06:58:18 ralf Exp $ */
 
 #ifndef BEVELBOX_H
 #define BEVELBOX_H
@@ -34,6 +34,9 @@ public:
   BevelBox(AGUIX *aguix,int x,int y,int width,int height,
            int state);
   virtual ~BevelBox();
+  BevelBox( const BevelBox &other );
+  BevelBox &operator=( const BevelBox &other );
+
   int getState() const;
   void setState(int);
   virtual void redraw();
