@@ -1,6 +1,6 @@
 /* button.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001 Ralf Hoffmann.
+ * Copyright (C) 2001-2004 Ralf Hoffmann.
  * You can contact me at: ralf.hoffmann@epost.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: button.h,v 1.8 2004/01/22 21:18:10 ralf Exp $ */
+/* $Id: button.h,v 1.9 2004/03/18 06:58:29 ralf Exp $ */
 
 #ifndef BUTTON_H
 #define BUTTON_H
@@ -43,6 +43,9 @@ public:
          int fg_normal,int fg_high,
          int bg_normal,int bg_high,int data);
   virtual ~Button();
+  Button( const Button &other );
+  Button &operator=( const Button &other );
+
   const char *getText(int) const;
   void setText(int,const char *);
   bool getDualState() const;
