@@ -1,6 +1,6 @@
 /* choosebutton.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001 Ralf Hoffmann.
+ * Copyright (C) 2001-2004 Ralf Hoffmann.
  * You can contact me at: ralf.hoffmann@epost.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: choosebutton.h,v 1.9 2004/01/22 21:18:20 ralf Exp $ */
+/* $Id: choosebutton.h,v 1.10 2004/03/18 06:58:44 ralf Exp $ */
 
 #ifndef CHOOSEBUTTON_H
 #define CHOOSEBUTTON_H
@@ -38,6 +38,9 @@ public:
   ChooseButton(AGUIX *aguix,int x,int y,bool state,
                const char *label,int labelpos,int labelcolor,int data);
   virtual ~ChooseButton();
+  ChooseButton( const ChooseButton &other );
+  ChooseButton &operator=( const ChooseButton &other );
+
   const char *getLabel() const;
   void setLabel(const char *);
   virtual void resize(int w,int h); // Notwendig, da Gre des ChooseButtons nicht die Gre
