@@ -1,6 +1,6 @@
 /* condvar.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2002 Ralf Hoffmann.
+ * Copyright (C) 2002-2004 Ralf Hoffmann.
  * You can contact me at: ralf.hoffmann@epost.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: condvar.h,v 1.3 2003/11/26 19:21:02 ralf Exp $ */
+/* $Id: condvar.h,v 1.4 2004/03/18 06:58:59 ralf Exp $ */
 
 #ifndef CONDVAR_H
 #define CONDVAR_H
@@ -31,6 +31,9 @@ class CondVar:public MutEx
 public:
   CondVar();
   ~CondVar();
+  CondVar( const CondVar &other );
+  CondVar &operator=( const CondVar &other );
+
   void wait();
   void signal();
   void bcast();
