@@ -1,6 +1,6 @@
 /* cyclebutton.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001 Ralf Hoffmann.
+ * Copyright (C) 2001-2004 Ralf Hoffmann.
  * You can contact me at: ralf.hoffmann@epost.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: cyclebutton.cc,v 1.17 2004/01/22 21:18:30 ralf Exp $ */
+/* $Id: cyclebutton.cc,v 1.19 2004/06/13 19:40:01 ralf Exp $ */
 
 #include "cyclebutton.h"
 #include "awindow.h"
@@ -99,6 +99,8 @@ char *CycleButton::getOption(int index2)
 
 int CycleButton::addOption(const char *new_text)
 {
+  if ( new_text == NULL ) return -1;
+
   options->addElement(dupstring(new_text));
   if(act_opt==-1) {
     act_opt=0;
@@ -107,6 +109,20 @@ int CycleButton::addOption(const char *new_text)
   return options->size()-1;
 }
 
+int CycleButton::setOption( int pos, const char *new_text )
+{
+  char *tstr;
+
+  if ( ( pos < 0 ) || ( pos >= options->size() ) ) return -1;
+  if ( new_text == NULL ) return -1;
+
+  tstr = (char*)options->exchangeElement( pos, dupstring( new_text ) );
+  _freesafe( tstr );
+
+  redraw();
+  return pos;
+}
+
 void CycleButton::setOption(int index2)
 {
   if((index2>=0)&&(index2<options->size())) {
