@@ -1,6 +1,6 @@
 /* cyclebutton.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001 Ralf Hoffmann.
+ * Copyright (C) 2001-2004 Ralf Hoffmann.
  * You can contact me at: ralf.hoffmann@epost.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: cyclebutton.h,v 1.5 2004/01/22 21:18:35 ralf Exp $ */
+/* $Id: cyclebutton.h,v 1.7 2004/06/13 19:40:10 ralf Exp $ */
 
 #ifndef CYCLEBUTTON_H
 #define CYCLEBUTTON_H
@@ -38,8 +38,12 @@ public:
   CycleButton(AGUIX *aguix,int x,int y,int width,int height,
               int fg,int bg,int data);
   virtual ~CycleButton();
+  CycleButton( const CycleButton &other );
+  CycleButton &operator=( const CycleButton &other );
+
   char *getOption(int);
   int addOption(const char *);
+  int setOption( int, const char * );
   int getSelectedOption() const;
   void setFG(int);
   int getFG() const;
