@@ -1,6 +1,6 @@
 /* dndelement.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001 Ralf Hoffmann.
+ * Copyright (C) 2001-2004 Ralf Hoffmann.
  * You can contact me at: ralf.hoffmann@epost.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: dndelement.h,v 1.6 2003/11/06 21:32:15 ralf Exp $ */
+/* $Id: dndelement.h,v 1.7 2004/03/18 06:59:33 ralf Exp $ */
 
 #ifndef DNDELEMENT_H
 #define DNDELEMENT_H
@@ -34,6 +34,9 @@ class DNDElement
 public:
   DNDElement( AGUIX * );
   virtual ~DNDElement();
+  DNDElement( const DNDElement &other );
+  DNDElement &operator=( const DNDElement &other );
+
   virtual void handler( Message *msg );
   virtual void redraw();
   virtual void create();
