@@ -1,6 +1,6 @@
 /* dndtext.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001 Ralf Hoffmann.
+ * Copyright (C) 2001-2004 Ralf Hoffmann.
  * You can contact me at: ralf.hoffmann@epost.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: dndtext.h,v 1.6 2003/11/06 21:32:29 ralf Exp $ */
+/* $Id: dndtext.h,v 1.7 2004/03/18 06:59:46 ralf Exp $ */
 
 #ifndef DNDTEXT_H
 #define DNDTEXT_H
@@ -33,6 +33,9 @@ class DNDText:public DNDElement
 public:
   DNDText( AGUIX *, char*, int, int, AGUIXFont* );
   virtual ~DNDText();
+  DNDText( const DNDText &other );
+  DNDText &operator=( const DNDText &other );
+
   virtual void redraw();
   virtual void create();
 protected:
