@@ -1,6 +1,6 @@
 /* fieldlistview.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2002 Ralf Hoffmann.
+ * Copyright (C) 2002-2004 Ralf Hoffmann.
  * You can contact me at: ralf.hoffmann@epost.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: fieldlistview.cc,v 1.54 2004/02/15 23:04:41 ralf Exp $ */
+/* $Id: fieldlistview.cc,v 1.56 2004/07/05 19:49:01 ralf Exp $ */
 
 #include "fieldlistview.h"
 #include <stdlib.h>
@@ -1016,7 +1016,7 @@ bool FieldListView::handleMessage( XEvent *E, Message *msg )
 	  if ( msg->button == Button3 ) handleThird( msg );
 	  else if ( ( msg->button == Button4 ) || ( msg->button == Button5 ) ) {
 	    gettimeofday( &t2, NULL );
-	    s = abs( t2.tv_sec - lastwheel.tv_sec );
+	    s = abs( (int)( t2.tv_sec - lastwheel.tv_sec ) );
 	    us = t2.tv_usec - lastwheel.tv_usec;
 	    if ( us < 0 ) {
 	      us += 1000000;
