@@ -1,6 +1,6 @@
 /* fieldlistview.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2002 Ralf Hoffmann.
+ * Copyright (C) 2002-2004 Ralf Hoffmann.
  * You can contact me at: ralf.hoffmann@epost.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: fieldlistview.h,v 1.22 2004/01/22 21:18:52 ralf Exp $ */
+/* $Id: fieldlistview.h,v 1.23 2004/03/18 07:00:03 ralf Exp $ */
 
 #ifndef NEWLISTVIEW_H
 #define NEWLISTVIEW_H
@@ -40,6 +40,9 @@ class FieldListView:public GUIElement
 public:
   FieldListView( AGUIX *caguix, int cx, int cy, int cwidth, int cheight, int cdata );
   virtual ~FieldListView();
+  FieldListView( const FieldListView &other );
+  FieldListView &operator=( const FieldListView &other );
+
   void setNrOfFields( int nv );
   void setText( int row, int field, std::string text );
   std::string getText( int row, int field ) const;
@@ -164,6 +167,8 @@ protected:
   public:
     Content();
     ~Content();
+    Content( const Content &other );
+    Content &operator=( const Content &other );
     void setText( int field, std::string text );
     void trim( int newfields );
     std::string getText( int field ) const;
