@@ -1,6 +1,6 @@
 /* fieldlistviewdnd.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2002 Ralf Hoffmann.
+ * Copyright (C) 2002-2004 Ralf Hoffmann.
  * You can contact me at: ralf.hoffmann@epost.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: fieldlistviewdnd.h,v 1.3 2004/01/22 21:19:01 ralf Exp $ */
+/* $Id: fieldlistviewdnd.h,v 1.4 2004/03/18 07:00:21 ralf Exp $ */
 
 #ifndef FIELDLISTVIEWDND_H
 #define FIELDLISTVIEWDND_H
@@ -32,6 +32,9 @@ class FieldListViewDND:public FieldListView
 public:
   FieldListViewDND( AGUIX *aguix, int x, int y, int width, int height, int data );
   virtual ~FieldListViewDND();
+  FieldListViewDND( const FieldListViewDND &other );
+  FieldListViewDND &operator=( const FieldListViewDND &other );
+
   virtual const char *getType() const;
   virtual bool isType(const char *type) const;
   void removealldndtexts();
