@@ -1,6 +1,6 @@
 /* fieldlvrowdata.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2003 Ralf Hoffmann.
+ * Copyright (C) 2003-2004 Ralf Hoffmann.
  * You can contact me at: ralf.hoffmann@epost.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: fieldlvrowdata.h,v 1.1 2003/11/06 21:37:40 ralf Exp $ */
+/* $Id: fieldlvrowdata.h,v 1.2 2004/03/18 07:00:49 ralf Exp $ */
 
 #ifndef FIELDLVROWDATA_H
 #define FIELDLVROWDATA_H
@@ -30,6 +30,9 @@ class FieldLVRowData
 public:
   FieldLVRowData();
   virtual ~FieldLVRowData();
+  FieldLVRowData( const FieldLVRowData &other );
+  FieldLVRowData &operator=( const FieldLVRowData &other );
+
   virtual FieldLVRowData *duplicate() const;
 private:
 };
