@@ -1,6 +1,6 @@
 /* guielement.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001 Ralf Hoffmann.
+ * Copyright (C) 2001-2004 Ralf Hoffmann.
  * You can contact me at: ralf.hoffmann@epost.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: guielement.h,v 1.15 2004/02/01 21:10:31 ralf Exp $ */
+/* $Id: guielement.h,v 1.16 2004/03/18 07:01:16 ralf Exp $ */
 
 #ifndef GUIELEMENT_H
 #define GUIELEMENT_H
@@ -31,9 +31,11 @@ class AWindow;
 
 class GUIElement {
 public:
-  GUIElement() {}
   GUIElement(AGUIX *aguix);
   virtual ~GUIElement();
+  GUIElement( const GUIElement &other );
+  GUIElement &operator=( const GUIElement &other );
+
   virtual void move(int x,int y);
   virtual void resize(int w,int h);
   virtual void redraw();
