@@ -1,6 +1,6 @@
 /* message.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001 Ralf Hoffmann.
+ * Copyright (C) 2001-2004 Ralf Hoffmann.
  * You can contact me at: ralf.hoffmann@epost.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: message.h,v 1.15 2003/12/09 22:39:05 ralf Exp $ */
+/* $Id: message.h,v 1.17 2004/06/13 19:47:35 ralf Exp $ */
 
 #ifndef MESSAGE_H
 #define MESSAGE_H
@@ -33,6 +33,7 @@ class GUIElement;
 class CycleButton;
 class AWindow;
 class FieldListView;
+class KarteiButton;
 
 typedef struct message
 {
@@ -63,7 +64,8 @@ enum {AG_NONE,AG_KEYPRESSED,AG_KEYRELEASED,AG_MOUSEPRESSED,AG_MOUSERELEASED,AG_M
       AG_SIZECHANGED,
       AG_DND_START,AG_DND_END,AG_DND_CANCEL,
       AG_CYCLEBUTTONCLICKED,
-      AG_FIELDLV_ONESELECT,AG_FIELDLV_MULTISELECT,AG_FIELDLV_PRESSED,AG_FIELDLV_HEADERCLICKED};
+      AG_FIELDLV_ONESELECT,AG_FIELDLV_MULTISELECT,AG_FIELDLV_PRESSED,AG_FIELDLV_HEADERCLICKED,
+      AG_KARTEIBUTTONCLICKED };
 
 typedef struct agkey {
   int type;
@@ -187,6 +189,14 @@ typedef AGFieldLV AGFieldLVOneSelect;
 typedef AGFieldLV AGFieldLVMultiSelect;
 typedef AGFieldLV AGFieldLVPressed;
 
+typedef struct agkarteibutton {
+  int type;
+  KarteiButton *karteibutton;
+  int option;
+} AGKarteiButton;
+
+typedef AGKarteiButton AGKarteiButtonClicked;
+
 typedef union agmessage {
   int type;
   AGKey key;
@@ -201,6 +211,7 @@ typedef union agmessage {
   AGDND dnd;
   AGCycleButton cyclebutton;
   AGFieldLV fieldlv;
+  AGKarteiButton karteibutton;
   long direct[20];
 } AGMessage;
 
