@@ -1,6 +1,6 @@
 /* mutex.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2002 Ralf Hoffmann.
+ * Copyright (C) 2002-2004 Ralf Hoffmann.
  * You can contact me at: ralf.hoffmann@epost.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: mutex.h,v 1.3 2002/03/08 19:04:55 ralf Exp $ */
+/* $Id: mutex.h,v 1.4 2004/03/18 07:02:18 ralf Exp $ */
 
 #ifndef MUTEX_H
 #define MUTEX_H
@@ -33,7 +33,9 @@ class MutEx
 {
 public:
   MutEx();
-  ~MutEx();
+  virtual ~MutEx();
+  MutEx( const MutEx &other );
+  MutEx &operator=( const MutEx &other );
   void lock();
   void unlock();
   bool trylock();
