@@ -1,6 +1,6 @@
 /* solidbutton.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001 Ralf Hoffmann.
+ * Copyright (C) 2001-2004 Ralf Hoffmann.
  * You can contact me at: ralf.hoffmann@epost.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: solidbutton.h,v 1.5 2004/01/22 21:19:36 ralf Exp $ */
+/* $Id: solidbutton.h,v 1.6 2004/03/18 07:03:02 ralf Exp $ */
 
 #ifndef SOLIDBUTTON_H
 #define SOLIDBUTTON_H
@@ -34,6 +34,8 @@ public:
   SolidButton(class AGUIX *aguix,int x,int y,int width,int height,
          const char *text,int fg,int bg,bool state);
   virtual ~SolidButton();
+  SolidButton( const SolidButton &other );
+  SolidButton &operator=( const SolidButton &other );
   const char *getText() const;
   void setText(const char *);
   void setFG(int);
