@@ -1,6 +1,6 @@
 /* stringgadget.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001 Ralf Hoffmann.
+ * Copyright (C) 2001-2004 Ralf Hoffmann.
  * You can contact me at: ralf.hoffmann@epost.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: stringgadget.h,v 1.14 2004/01/22 21:19:45 ralf Exp $ */
+/* $Id: stringgadget.h,v 1.15 2004/03/18 07:03:18 ralf Exp $ */
 
 #ifndef STRINGGADGET_H
 #define STRINGGADGET_H
@@ -32,6 +32,8 @@ public:
   StringGadget(class AGUIX *aguix,int x,int y,int width,int height,const char *text,int data);
   StringGadget(class AGUIX *aguix,int x,int y,int width,const char *text,int data);
   virtual ~StringGadget();
+  StringGadget( const StringGadget &other );
+  StringGadget &operator=( const StringGadget &other );
   void resize(int w,int h);
   int getData() const;
   void setData(int);
