@@ -1,6 +1,6 @@
 /* text.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001 Ralf Hoffmann.
+ * Copyright (C) 2001-2004 Ralf Hoffmann.
  * You can contact me at: ralf.hoffmann@epost.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: text.h,v 1.5 2004/01/22 21:19:54 ralf Exp $ */
+/* $Id: text.h,v 1.6 2004/03/18 07:03:30 ralf Exp $ */
 
 #ifndef TEXT_H
 #define TEXT_H
@@ -31,6 +31,8 @@ public:
   Text(class AGUIX *aguix);
   Text(class AGUIX *aguix,int x,int y,const char *text,int color);
   virtual ~Text();
+  Text( const Text &other );
+  Text &operator=( const Text &other );
   const char *getText() const;
   void setText(const char *);
   int getColor() const;
