@@ -1,6 +1,6 @@
 /* util.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001 Ralf Hoffmann.
+ * Copyright (C) 2001-2004 Ralf Hoffmann.
  * You can contact me at: ralf.hoffmann@epost.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: util.cc,v 1.14 2004/01/22 21:19:59 ralf Exp $ */
+/* $Id: util.cc,v 1.16 2004/06/13 19:47:59 ralf Exp $ */
 
 #include "util.h"
 #include "lowlevelfunc.h"
@@ -915,6 +915,9 @@ int createLines(const char *text,char ***ret_lines)
       }
       for ( p = j = 0; liness[i][j] != '\0'; j++ ) {
         if ( ( liness[i][j] == '\\' ) && ( liness[i][j+1] == '|' ) ) {
+	  liness[i][p++] = liness[i][++j];
+        } else if ( ( liness[i][j] == '\\' ) && ( liness[i][j+1] == '\\' ) ) {
+	  liness[i][p++] = liness[i][++j];
 	} else {
 	  liness[i][p++] = liness[i][j];
 	}
