@@ -1,6 +1,6 @@
 /* util.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001 Ralf Hoffmann.
+ * Copyright (C) 2001-2004 Ralf Hoffmann.
  * You can contact me at: ralf.hoffmann@epost.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: util.h,v 1.8 2004/01/22 21:20:03 ralf Exp $ */
+/* $Id: util.h,v 1.9 2004/03/18 07:03:54 ralf Exp $ */
 
 #ifndef UTIL_H
 #define UTIL_H
@@ -30,6 +30,8 @@ class ListElement
  public:
   ListElement();
   ~ListElement();
+  ListElement( const ListElement &other );
+  ListElement &operator=( const ListElement &other );
   void *element;
   ListElement *next;
   ListElement *prev;
@@ -40,6 +42,8 @@ class List
 public:
   List();
   ~List();
+  List( const List &other );
+  List &operator=( const List &other );
   int addElement(void*);
   int addElementAt(int,void *);
   int removeElement(void *);
@@ -90,6 +94,8 @@ class ArrayList
 public:
   ArrayList();
   ~ArrayList();
+  ArrayList( const ArrayList &other );
+  ArrayList &operator=( const ArrayList &other );
   int addElement(void*);
   int addElementAt(int,void *);
   int removeElement(void *);
