@@ -1,6 +1,6 @@
 /* basic_actions.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001 Ralf Hoffmann.
+ * Copyright (C) 2001-2004 Ralf Hoffmann.
  * You can contact me at: ralf.hoffmann@epost.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: basic_actions.h,v 1.7 2003/05/04 00:34:34 ralf Exp $ */
+/* $Id: basic_actions.h,v 1.9 2004/07/21 21:10:00 ralf Exp $ */
 
 #ifndef BASIC_ACTIONS_H
 #define BASIC_ACTIONS_H
@@ -31,9 +31,15 @@ class DNDAction:public FunctionProto
 public:
   DNDAction();
   virtual ~DNDAction();
+  DNDAction( const DNDAction &other );
+  DNDAction &operator=( const DNDAction &other );
+
   virtual DNDAction *duplicate() const;
   virtual bool isName(const char *);
   virtual const char *getName();
+#if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
+  using FunctionProto::run;
+#endif
   virtual int run(ActionMessage*);
   virtual const char *getDescription();
 protected:
@@ -46,9 +52,15 @@ class DoubleClickAction:public FunctionProto
 public:
   DoubleClickAction();
   virtual ~DoubleClickAction();
+  DoubleClickAction( const DoubleClickAction &other );
+  DoubleClickAction &operator=( const DoubleClickAction &other );
+
   virtual DoubleClickAction *duplicate() const;
   virtual bool isName(const char *);
   virtual const char *getName();
+#if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
+  using FunctionProto::run;
+#endif
   virtual int run(ActionMessage*);
   virtual const char *getDescription();
 protected:
@@ -61,9 +73,15 @@ class ShowAction:public FunctionProto
 public:
   ShowAction();
   virtual ~ShowAction();
+  ShowAction( const ShowAction &other );
+  ShowAction &operator=( const ShowAction &other );
+
   virtual ShowAction *duplicate() const;
   virtual bool isName(const char *);
   virtual const char *getName();
+#if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
+  using FunctionProto::run;
+#endif
   virtual int run(ActionMessage*);
   virtual const char *getDescription();
 protected:
@@ -76,9 +94,15 @@ class RawShowAction:public FunctionProto
 public:
   RawShowAction();
   virtual ~RawShowAction();
+  RawShowAction( const RawShowAction &other );
+  RawShowAction &operator=( const RawShowAction &other );
+
   virtual RawShowAction *duplicate() const;
   virtual bool isName(const char *);
   virtual const char *getName();
+#if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
+  using FunctionProto::run;
+#endif
   virtual int run(ActionMessage*);
   virtual const char *getDescription();
 protected:
@@ -91,9 +115,15 @@ class UserAction:public FunctionProto
 public:
   UserAction();
   virtual ~UserAction();
+  UserAction( const UserAction &other );
+  UserAction &operator=( const UserAction &other );
+
   virtual UserAction *duplicate() const;
   virtual bool isName(const char *);
   virtual const char *getName();
+#if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
+  using FunctionProto::run;
+#endif
   virtual int run(ActionMessage*);
   virtual const char *getDescription();
   virtual bool save(Datei*);
@@ -111,9 +141,15 @@ class ChangeHiddenFlag:public FunctionProto
 public:
   ChangeHiddenFlag();
   virtual ~ChangeHiddenFlag();
+  ChangeHiddenFlag( const ChangeHiddenFlag &other );
+  ChangeHiddenFlag &operator=( const ChangeHiddenFlag &other );
+
   virtual ChangeHiddenFlag *duplicate() const;
   virtual bool isName(const char *);
   virtual const char *getName();
+#if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
+  using FunctionProto::run;
+#endif
   virtual int run(ActionMessage*);
   virtual bool save(Datei*);
   virtual const char *getDescription();
