@@ -1,6 +1,6 @@
 /* changesymlinkop.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001 Ralf Hoffmann.
+ * Copyright (C) 2001-2004 Ralf Hoffmann.
  * You can contact me at: ralf.hoffmann@epost.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: changesymlinkop.h,v 1.6 2003/05/04 00:35:34 ralf Exp $ */
+/* $Id: changesymlinkop.h,v 1.8 2004/07/21 21:12:08 ralf Exp $ */
 
 #ifndef CHANGESYMLINKOP_H
 #define CHANGESYMLINKOP_H
@@ -37,9 +37,15 @@ class ChangeSymlinkOp:public FunctionProto
 public:
   ChangeSymlinkOp();
   virtual ~ChangeSymlinkOp();
+  ChangeSymlinkOp( const ChangeSymlinkOp &other );
+  ChangeSymlinkOp &operator=( const ChangeSymlinkOp &other );
+
   virtual ChangeSymlinkOp *duplicate() const;
   virtual bool isName(const char *);
   virtual const char *getName();
+#if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
+  using FunctionProto::run;
+#endif
   virtual int run(ActionMessage*);
   virtual const char *getDescription();
 protected:
