@@ -283,12 +283,14 @@
      LAYOUT_WCP = 506,
      BUTTONSVERT_WCP = 507,
      LISTVIEWSVERT_WCP = 508,
-     ERROR = 509,
-     ACTIVESIDE_WCP = 510,
-     SHOWFREESPACE_WCP = 511,
-     ACTIVEMODE_WCP = 512,
-     STRING_WCP = 513,
-     NUM_WCP = 514
+     EXTCOND_WCP = 509,
+     USEEXTCOND_WCP = 510,
+     ERROR = 511,
+     ACTIVESIDE_WCP = 512,
+     SHOWFREESPACE_WCP = 513,
+     ACTIVEMODE_WCP = 514,
+     STRING_WCP = 515,
+     NUM_WCP = 516
    };
 #endif
 #define LEFTBRACE_WCP 258
@@ -542,12 +544,14 @@
 #define LAYOUT_WCP 506
 #define BUTTONSVERT_WCP 507
 #define LISTVIEWSVERT_WCP 508
-#define ERROR 509
-#define ACTIVESIDE_WCP 510
-#define SHOWFREESPACE_WCP 511
-#define ACTIVEMODE_WCP 512
-#define STRING_WCP 513
-#define NUM_WCP 514
+#define EXTCOND_WCP 509
+#define USEEXTCOND_WCP 510
+#define ERROR 511
+#define ACTIVESIDE_WCP 512
+#define SHOWFREESPACE_WCP 513
+#define ACTIVEMODE_WCP 514
+#define STRING_WCP 515
+#define NUM_WCP 516
 
 
 
@@ -559,7 +563,7 @@ typedef union {
   char *strptr;
 } yystype;
 /* Line 1281 of /usr/share/bison/yacc.c.  */
-#line 563 "configparser.tab.h"
+#line 567 "configparser.tab.h"
 # define YYSTYPE yystype
 #endif
 
