@@ -1,6 +1,6 @@
 /* copyop.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001 Ralf Hoffmann.
+ * Copyright (C) 2001-2004 Ralf Hoffmann.
  * You can contact me at: ralf.hoffmann@epost.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: copyop.cc,v 1.60 2004/01/21 21:41:56 ralf Exp $ */
+/* $Id: copyop.cc,v 1.62 2004/07/01 18:55:46 ralf Exp $ */
 
 #include "listermode.h"
 #include "normalmode.h"
@@ -301,7 +301,8 @@ CopyOp::normalmodecopy()
       }
       copyorder.destdir=dest;
       // now start copy process
-      copyorder.cowin=new CopyOpWin( am->getWorker()->getAGUIX());
+      copyorder.cowin=new CopyOpWin( am->getWorker()->getAGUIX(),
+                                     copyorder.move );
       nm1->copy(&copyorder);
       delete copyorder.cowin;
     }
@@ -676,7 +677,7 @@ void CopyOp::setFastcopy( fastcopy_t nv )
  * Class CopyOpWin *
  *******************/
 
-CopyOpWin::CopyOpWin(AGUIX*taguix)
+CopyOpWin::CopyOpWin( AGUIX*taguix, bool _move )
 {
   this->aguix=taguix;
   source=dupstring("");
@@ -710,6 +711,8 @@ CopyOpWin::CopyOpWin(AGUIX*taguix)
   lastrate = 0.0;
   
   glob_percent = 0;
+  
+  move = _move;
 }
 
 CopyOpWin::~CopyOpWin()
@@ -731,7 +734,10 @@ CopyOpWin::open(bool tslim)
   window=new AWindow(aguix);
   w=400;
   h=10;
-  window->create(NULL,10,10,w,h,0,catalog.getLocaleCom(8));
+  window->create( NULL,
+                  10, 10,
+                  w, h,
+                  0, ( move == true ) ? catalog.getLocale( 299 ) : catalog.getLocaleCom( 8 ) );
   tx=5;
   ty=5;
   sourcetext=(Text*)window->add(new Text(aguix,tx,ty,"",1));
@@ -803,7 +809,7 @@ CopyOpWin::open(bool tslim)
   window->show();
 
   filenamespace[0] = ( w - window->getBorderWidth() - sourcetext->getX() ) / aguix->getCharWidth();
-  filenamespace[0] -= strlen(catalog.getLocale(116)) - 2;
+  filenamespace[0] -= strlen( catalog.getLocale( ( move == true ) ? 594 : 116 ) ) - 2;
   filenamespace[1] = ( w - window->getBorderWidth() - desttext->getX() ) / aguix->getCharWidth();
   filenamespace[1] -= strlen(catalog.getLocale(117)) - 2;
 
@@ -939,12 +945,12 @@ CopyOpWin::redraw()
       tstr3 = Datei::shrinkFilename( source, filenamespace[0] );
       if ( tstr3 == NULL)
         tstr3 = dupstring( source );
-      tstr2 = (char*)_allocsafe( strlen( catalog.getLocale( 116 ) ) + strlen( tstr3 ) + 1 );
-      sprintf( tstr2, catalog.getLocale( 116 ), tstr3 );
+      tstr2 = (char*)_allocsafe( strlen( catalog.getLocale( ( move == true ) ? 594 : 116 ) ) + strlen( tstr3 ) + 1 );
+      sprintf( tstr2, catalog.getLocale( ( move == true ) ? 594 : 116 ), tstr3 );
       _freesafe( tstr3 );
     } else {
-      tstr2 = (char*)_allocsafe( strlen( catalog.getLocale( 116 ) ) + 1 );
-      sprintf( tstr2, catalog.getLocale( 116 ), "" );
+      tstr2 = (char*)_allocsafe( strlen( catalog.getLocale( ( move == true ) ? 594 : 116 ) ) + 1 );
+      sprintf( tstr2, catalog.getLocale( ( move == true ) ? 594 : 116 ), "" );
     }
     sourcetext->setText(tstr2);
     _freesafe(tstr2);
@@ -1047,14 +1053,17 @@ CopyOpWin::redraw()
       newglob_percent = (int)( rate * 100.0 );
       if ( newglob_percent != glob_percent ) {
         glob_percent = newglob_percent;
-        tstr3 = (char*)_allocsafe( strlen( catalog.getLocaleCom( 8 ) ) +
+        tstr3 = (char*)_allocsafe( strlen( ( move == true ) ? catalog.getLocale( 299 ) : catalog.getLocaleCom( 8 ) ) +
                                    strlen( " ( %)" ) + 
                                    A_BYTESFORNUMBER( glob_percent ) +
                                    1 );
         if ( ( glob_percent > 0 ) && ( glob_percent <= 100 ) ) {
-          sprintf( tstr3, "%s (%d %%)", catalog.getLocaleCom( 8 ), glob_percent );
+          sprintf( tstr3, "%s (%d %%)",
+                   ( move == true ) ? catalog.getLocale( 299 ) : catalog.getLocaleCom( 8 ),
+                   glob_percent );
         } else {
-          sprintf( tstr3, "%s", catalog.getLocaleCom( 8 ) );
+          sprintf( tstr3, "%s",
+                   ( move == true ) ? catalog.getLocale( 299 ) : catalog.getLocaleCom( 8 ) );
         }
         window->setTitle( tstr3 );
         _freesafe( tstr3 );
@@ -1142,7 +1151,7 @@ CopyOpWin::redraw()
                       msg->size.newh - window->getBorderWidth() - cb->getHeight() );
             
             filenamespace[0] = ( msg->size.neww - window->getBorderWidth() - sourcetext->getX() ) / aguix->getCharWidth();
-            filenamespace[0] -= strlen(catalog.getLocale(116)) - 2;
+            filenamespace[0] -= strlen( catalog.getLocale( ( move == true ) ? 594 : 116 ) ) - 2;
             filenamespace[1] = ( msg->size.neww - window->getBorderWidth() - desttext->getX() ) / aguix->getCharWidth();
             filenamespace[1] -= strlen(catalog.getLocale(117)) - 2;
             update_sourcetext = true;
