@@ -1,6 +1,6 @@
 /* copyop.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001 Ralf Hoffmann.
+ * Copyright (C) 2001-2004 Ralf Hoffmann.
  * You can contact me at: ralf.hoffmann@epost.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: copyop.h,v 1.25 2004/01/21 21:41:18 ralf Exp $ */
+/* $Id: copyop.h,v 1.28 2004/07/21 21:12:26 ralf Exp $ */
 
 #ifndef COPYOP_H
 #define COPYOP_H
@@ -38,9 +38,15 @@ class CopyOp:public FunctionProto
 public:
   CopyOp();
   virtual ~CopyOp();
+  CopyOp( const CopyOp &other );
+  CopyOp &operator=( const CopyOp &other );
+
   virtual CopyOp *duplicate() const;
   virtual bool isName(const char *);
   virtual const char *getName();
+#if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
+  using FunctionProto::run;
+#endif
   virtual int run(ActionMessage*);
   virtual bool save(Datei*);
   virtual const char *getDescription();
@@ -94,8 +100,11 @@ protected:
 class CopyOpWin
 {
 public:
-  CopyOpWin(AGUIX*);
+  CopyOpWin( AGUIX*, bool _move = false );
   ~CopyOpWin();
+  CopyOpWin( const CopyOpWin &other );
+  CopyOpWin &operator=( const CopyOpWin &other );
+
   int open(bool slim);
   void close();
   void starttimer(); // called once to set timer
@@ -180,6 +189,7 @@ protected:
    8.<copied Bytes>/<bytes> @ <rate>
 */
   int glob_percent;
+  bool move;
 };
 
 #endif
