@@ -1,6 +1,6 @@
 /* createsymlinkop.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001 Ralf Hoffmann.
+ * Copyright (C) 2001-2004 Ralf Hoffmann.
  * You can contact me at: ralf.hoffmann@epost.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: createsymlinkop.h,v 1.7 2003/05/04 00:43:51 ralf Exp $ */
+/* $Id: createsymlinkop.h,v 1.9 2004/07/21 21:12:30 ralf Exp $ */
 
 #ifndef CREATESYMLINKOP_H
 #define CREATESYMLINKOP_H
@@ -37,9 +37,15 @@ class CreateSymlinkOp:public FunctionProto
 public:
   CreateSymlinkOp();
   virtual ~CreateSymlinkOp();
+  CreateSymlinkOp( const CreateSymlinkOp &other );
+  CreateSymlinkOp &operator=( const CreateSymlinkOp &other );
+
   virtual CreateSymlinkOp *duplicate() const;
   virtual bool isName(const char *);
   virtual const char *getName();
+#if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
+  using FunctionProto::run;
+#endif
   virtual int run(ActionMessage*);
   virtual bool save(Datei*);
   virtual const char *getDescription();
