@@ -1,6 +1,6 @@
 /* cursorops.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001 Ralf Hoffmann.
+ * Copyright (C) 2001-2004 Ralf Hoffmann.
  * You can contact me at: ralf.hoffmann@epost.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: cursorops.h,v 1.8 2003/05/04 00:46:00 ralf Exp $ */
+/* $Id: cursorops.h,v 1.10 2004/07/21 21:12:36 ralf Exp $ */
 
 #ifndef CURSOROPS_H
 #define CURSOROPS_H
@@ -32,9 +32,15 @@ class RowUp:public FunctionProto
 public:
   RowUp();
   virtual ~RowUp();
+  RowUp( const RowUp &other );
+  RowUp &operator=( const RowUp &other );
+
   virtual RowUp *duplicate() const;
   virtual bool isName(const char *);
   virtual const char *getName();
+#if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
+  using FunctionProto::run;
+#endif
   virtual int run(ActionMessage*);
   virtual const char *getDescription();
 protected:
@@ -46,9 +52,15 @@ class RowDown:public FunctionProto
 public:
   RowDown();
   virtual ~RowDown();
+  RowDown( const RowDown &other );
+  RowDown &operator=( const RowDown &other );
+
   virtual RowDown *duplicate() const;
   virtual bool isName(const char *);
   virtual const char *getName();
+#if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
+  using FunctionProto::run;
+#endif
   virtual int run(ActionMessage*);
   virtual const char *getDescription();
 protected:
@@ -60,9 +72,15 @@ class FirstRow:public FunctionProto
 public:
   FirstRow();
   virtual ~FirstRow();
+  FirstRow( const FirstRow &other );
+  FirstRow &operator=( const FirstRow &other );
+
   virtual FirstRow *duplicate() const;
   virtual bool isName(const char *);
   virtual const char *getName();
+#if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
+  using FunctionProto::run;
+#endif
   virtual int run(ActionMessage*);
   virtual const char *getDescription();
 protected:
@@ -74,9 +92,15 @@ class LastRow:public FunctionProto
 public:
   LastRow();
   virtual ~LastRow();
+  LastRow( const LastRow &other );
+  LastRow &operator=( const LastRow &other );
+
   virtual LastRow *duplicate() const;
   virtual bool isName(const char *);
   virtual const char *getName();
+#if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
+  using FunctionProto::run;
+#endif
   virtual int run(ActionMessage*);
   virtual const char *getDescription();
 protected:
@@ -88,9 +112,15 @@ class PageUp:public FunctionProto
 public:
   PageUp();
   virtual ~PageUp();
+  PageUp( const PageUp &other );
+  PageUp &operator=( const PageUp &other );
+
   virtual PageUp *duplicate() const;
   virtual bool isName(const char *);
   virtual const char *getName();
+#if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
+  using FunctionProto::run;
+#endif
   virtual int run(ActionMessage*);
   virtual const char *getDescription();
 protected:
@@ -102,9 +132,15 @@ class PageDown:public FunctionProto
 public:
   PageDown();
   virtual ~PageDown();
+  PageDown( const PageDown &other );
+  PageDown &operator=( const PageDown &other );
+
   virtual PageDown *duplicate() const;
   virtual bool isName(const char *);
   virtual const char *getName();
+#if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
+  using FunctionProto::run;
+#endif
   virtual int run(ActionMessage*);
   virtual const char *getDescription();
 protected:
@@ -116,9 +152,15 @@ class SelectOp:public FunctionProto
 public:
   SelectOp();
   virtual ~SelectOp();
+  SelectOp( const SelectOp &other );
+  SelectOp &operator=( const SelectOp &other );
+
   virtual SelectOp *duplicate() const;
   virtual bool isName(const char *);
   virtual const char *getName();
+#if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
+  using FunctionProto::run;
+#endif
   virtual int run(ActionMessage*);
   virtual const char *getDescription();
 protected:
@@ -130,9 +172,15 @@ class SelectAllOp:public FunctionProto
 public:
   SelectAllOp();
   virtual ~SelectAllOp();
+  SelectAllOp( const SelectAllOp &other );
+  SelectAllOp &operator=( const SelectAllOp &other );
+
   virtual SelectAllOp *duplicate() const;
   virtual bool isName(const char *);
   virtual const char *getName();
+#if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
+  using FunctionProto::run;
+#endif
   virtual int run(ActionMessage*);
   virtual const char *getDescription();
 protected:
@@ -144,9 +192,15 @@ class SelectNoneOp:public FunctionProto
 public:
   SelectNoneOp();
   virtual ~SelectNoneOp();
+  SelectNoneOp( const SelectNoneOp &other );
+  SelectNoneOp &operator=( const SelectNoneOp &other );
+
   virtual SelectNoneOp *duplicate() const;
   virtual bool isName(const char *);
   virtual const char *getName();
+#if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
+  using FunctionProto::run;
+#endif
   virtual int run(ActionMessage*);
   virtual const char *getDescription();
 protected:
@@ -158,9 +212,15 @@ class InvertAllOp:public FunctionProto
 public:
   InvertAllOp();
   virtual ~InvertAllOp();
+  InvertAllOp( const InvertAllOp &other );
+  InvertAllOp &operator=( const InvertAllOp &other );
+
   virtual InvertAllOp *duplicate() const;
   virtual bool isName(const char *);
   virtual const char *getName();
+#if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
+  using FunctionProto::run;
+#endif
   virtual int run(ActionMessage*);
   virtual const char *getDescription();
 protected:
@@ -172,9 +232,15 @@ class ParentDirOp:public FunctionProto
 public:
   ParentDirOp();
   virtual ~ParentDirOp();
+  ParentDirOp( const ParentDirOp &other );
+  ParentDirOp &operator=( const ParentDirOp &other );
+
   virtual ParentDirOp *duplicate() const;
   virtual bool isName(const char *);
   virtual const char *getName();
+#if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
+  using FunctionProto::run;
+#endif
   virtual int run(ActionMessage*);
   virtual const char *getDescription();
 protected:
@@ -186,10 +252,16 @@ class EnterDirOp:public FunctionProto
 public:
   EnterDirOp();
   virtual ~EnterDirOp();
+  EnterDirOp( const EnterDirOp &other );
+  EnterDirOp &operator=( const EnterDirOp &other );
+
   virtual EnterDirOp *duplicate() const;
   virtual int configure();
   virtual bool isName(const char *);
   virtual const char *getName();
+#if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
+  using FunctionProto::run;
+#endif
   virtual int run( WPUContext *, ActionMessage* );
   virtual const char *getDescription();
   virtual bool save(Datei *);
