@@ -1,6 +1,6 @@
 /* datei.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001 Ralf Hoffmann.
+ * Copyright (C) 2001-2004 Ralf Hoffmann.
  * You can contact me at: ralf.hoffmann@epost.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: datei.cc,v 1.88 2004/03/10 22:34:37 ralf Exp $ */
+/* $Id: datei.cc,v 1.90 2004/06/13 21:24:59 ralf Exp $ */
 
 #include "datei.h"
 #include <aguix/lowlevelfunc.h>
@@ -29,6 +29,8 @@
 #include "pdatei.h"
 #include "worker.h"
 #include "nmrowdata.h"
+#include "condparser.h"
+#include "stringbuf.h"
 
 #if 0
 #include <string>
@@ -299,12 +301,19 @@ FileEntry::FileEntry()
   
   memset( &statbuf, 0, sizeof( statbuf ) );
   memset( &dstatbuf, 0, sizeof( dstatbuf ) );
+  
+  contentBuf.content = NULL;
+  contentBuf.size = 0;
+  
+  outputBuf = NULL;
 }
 
 FileEntry::~FileEntry()
 {
   if(name!=NULL) _freesafe(name);
   if(fullname!=NULL) _freesafe(fullname);
+  freeContentBuf();
+  freeOutputBuf();
 }
 
 Verzeichnis::Verzeichnis()
@@ -1214,7 +1223,7 @@ int getDatelen()
 
 #define FILEOUTPUTLENGTH 4096
 
-WCFiletype* FileEntry::checkFiletype( List *ftlist, bool skipcontent )
+WCFiletype* FileEntry::checkFiletype( List *ftlist, bool skipcontent, CondParser *condparser )
 {
 //printf("start check %s\n",name);
   unsigned char fbuffer[64];
@@ -1223,6 +1232,7 @@ WCFiletype* FileEntry::checkFiletype( List *ftlist, bool skipcontent )
   WCFiletype *ft,*unknownft;
   WCFiletype *foundft = NULL;
   const char *tstr1;
+  CondParser *localparser = NULL;
 
 #if 0
   char *filestr, *outname, *fileoutput;
@@ -1259,16 +1269,9 @@ WCFiletype* FileEntry::checkFiletype( List *ftlist, bool skipcontent )
     // Wirklich ein Verzeichnis
     return filetype;
   }
-  if ( ( ( isLink == true ) &&
-         ( !S_ISREG( dstatbuf.mode ) ) ) ||
-       ( ( isLink == false ) &&
-         ( !S_ISREG( statbuf.mode ) ) ) ) {
-    // Keine regulaere Datei
-    return filetype;
-  }
-  if ( statbuf.size < 1 ) {
-    return filetype;
-  }
+  
+  if ( isReg() == false ) skipcontent = true;
+  if ( statbuf.size < 1 ) skipcontent = true;
 
   id=ftlist->initEnum();
   if(skipcontent==false) {
@@ -1360,6 +1363,27 @@ WCFiletype* FileEntry::checkFiletype( List *ftlist, bool skipcontent )
 #endif
     }
   }
+
+  /* if no type found then check extended pattern */
+  if ( foundft == NULL ) {
+    ft = (WCFiletype*)ftlist->getFirstElement( id );
+    while ( ft != NULL ) {
+      if ( ft->getinternID() == NORMALTYPE ) {
+        if ( ft->getUseExtCond() == true ) {
+          if ( condparser == NULL ) {
+            localparser = new CondParser();
+            condparser = localparser;
+          }
+          if ( condparser->parse( ft->getExtCond(), this ) == 1 ) {
+            foundft = ft;
+            break;
+          }
+        }
+      }
+      ft = (WCFiletype*)ftlist->getNextElement( id );
+    }
+  }
+
   /* if no type found then check the pattern */
   if ( foundft == NULL ) {
     ft = (WCFiletype*)ftlist->getFirstElement( id );
@@ -1386,6 +1410,11 @@ WCFiletype* FileEntry::checkFiletype( List *ftlist, bool skipcontent )
     filetype = foundft;
   }
   ftlist->closeEnum( id );
+  
+  // free temporary buffers
+  if ( localparser != NULL ) delete localparser;
+  freeContentBuf();
+  freeOutputBuf();
 //printf("end check\n");
   return filetype;
 }
@@ -1525,15 +1554,18 @@ char *Datei::getNameWithoutExt(const char *name)
   return tstr;
 }
 
+/* THREADSAFE */
 char *Datei::createTMPName( const char *infix )
 {
   char *returnstr,buffer[ 2 * A_BYTESFORNUMBER( int ) ];
   int rannr;
   static int lfdnr = 0;
   FILE *tfp;
+  static MutEx lock;
   
   if ( infix == NULL ) infix = "";
   
+  lock.lock();
   for(;;) {
     rannr=rand();
     sprintf( buffer, "%d%d", lfdnr++, rannr );
@@ -1548,6 +1580,7 @@ char *Datei::createTMPName( const char *infix )
     chmod( returnstr, S_IRUSR | S_IWUSR );
     fclose( tfp );
   }
+  lock.unlock();
   return returnstr;
 }
 
@@ -2213,3 +2246,144 @@ bool FileEntry::checkAccess( int m )
   return ( access( fullname, m ) == 0 ) ? true : false;
 }
 
+char *FileEntry::getContentStr( int pos, int len )
+{
+  char *resstr = NULL;
+  int mylen, i;
+
+  if ( pos < 0 ) return dupstring( "" );
+  if ( len < 1 ) return dupstring( "" );
+
+  if ( contentBuf.content == NULL ) readContentBuf();
+  if ( contentBuf.content != NULL ) {
+    mylen = a_min( len, contentBuf.size - pos );
+    if ( mylen > 0 ) {
+      resstr = (char*)_allocsafe( mylen + 1 );
+      for ( i = 0; i < mylen; i++ ) {
+        resstr[i] = contentBuf.content[i+pos];
+      }
+      resstr[i] = '\0';
+    }
+  }
+  
+  return ( resstr != NULL ) ? resstr : dupstring( "" );
+}
+
+int FileEntry::getContentNum( int pos, int len )
+{
+  int mylen, i;
+  int res = -1;
+
+  if ( pos < 0 ) return -1;
+  if ( len < 1 ) return -1;
+  
+  if ( contentBuf.content == NULL ) readContentBuf();
+  if ( contentBuf.content != NULL ) {
+    mylen = a_min( len, contentBuf.size - pos );
+    if ( mylen > 0 ) {
+      res = 0;
+      for ( i = 0; i < mylen; i++ ) {
+        res <<= 8;
+        res += (unsigned char)contentBuf.content[i+pos];
+      }
+    }
+  }
+  
+  return res;
+}
+
+void FileEntry::freeContentBuf()
+{
+  if ( contentBuf.content != NULL ) {
+    _freesafe( contentBuf.content );
+    contentBuf.content = NULL;
+    contentBuf.size = 0;
+  }
+}
+
+void FileEntry::readContentBuf( int len )
+{
+  int reads, i;
+  unsigned char fbuffer[64];
+  PDatei *pfp;
+  
+  if ( isReg() == false ) return;
+  if ( ( len < 1 ) || ( len > 64 ) ) return;
+  if ( contentBuf.content == NULL ) {
+    reads = -1;
+    pfp = new PDatei();
+    if ( pfp->open( fullname ) == 0 ) {
+      reads = pfp->read( fbuffer, 64 );
+    }
+    delete pfp;
+    if ( reads > 0 ) {
+      contentBuf.content = (char*)_allocsafe( len + 1 );
+      contentBuf.size = reads;
+      for ( i = 0; i < reads; i++ ) {
+        contentBuf.content[i] = (char)fbuffer[i];
+      }
+      for ( i = reads; i < ( 64 + 1 ); i++ ) {
+        contentBuf.content[i] = '\0';
+      }
+    }
+  }
+}
+
+void FileEntry::freeOutputBuf()
+{
+  if ( outputBuf != NULL ) {
+    delete outputBuf;
+    outputBuf = NULL;
+  }
+}
+
+const char *FileEntry::findOutput( const char *tcommand )
+{
+  if ( outputBuf == NULL ) {
+    outputBuf = new StringBuf();
+  } else {
+    return outputBuf->find( tcommand );
+  }
+  return NULL;
+}
+
+void FileEntry::addOutput( const char *tcommand, const char *toutput, int value )
+{
+  if ( outputBuf == NULL ) outputBuf = new StringBuf();
+  
+  outputBuf->add( tcommand, toutput, value );
+}
+
+int FileEntry::findReturnvalue( const char *tcommand, int *return_value )
+{
+  if ( outputBuf == NULL ) {
+    outputBuf = new StringBuf();
+  } else {
+    return outputBuf->findValue( tcommand, return_value );
+  }
+  return -1;
+}
+
+int FileEntry::findOutputAndRV( const char *tcommand,
+                                const char **return_output,
+                                int *return_value )
+{
+  if ( outputBuf == NULL ) {
+    outputBuf = new StringBuf();
+  } else {
+    return outputBuf->find( tcommand, return_output, return_value );
+  }
+  return -1;
+}
+
+bool FileEntry::isReg() const
+{
+  if ( isLink == false ) {
+    if ( S_ISREG( statbuf.mode ) ) return true;
+    else return false;
+  }
+  if ( isCorrupt == true ) return false;
+  if ( S_ISREG( dstatbuf.mode ) ) return true;
+  return false;
+}
+
