@@ -1,6 +1,6 @@
 /* datei.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001 Ralf Hoffmann.
+ * Copyright (C) 2001-2004 Ralf Hoffmann.
  * You can contact me at: ralf.hoffmann@epost.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: datei.h,v 1.47 2004/03/10 22:34:44 ralf Exp $ */
+/* $Id: datei.h,v 1.49 2004/06/13 21:26:51 ralf Exp $ */
 
 #ifndef DATEI_H
 #define DATEI_H
@@ -59,6 +59,9 @@ class Datei
 public:
   Datei();
   ~Datei();
+  Datei( const Datei &other );
+  Datei &operator=( const Datei &other );
+
   int open( const char *name, const char *mode );
   void close();
   int putUChar(unsigned char value);
@@ -106,6 +109,9 @@ class FileEntry
 public:
   FileEntry();
   ~FileEntry();
+  FileEntry( const FileEntry &other );
+  FileEntry &operator=( const FileEntry &other );
+
   bool isDir();
   FileEntry *duplicate();
   int readInfos();
@@ -114,7 +120,7 @@ public:
   int writeDestination2Buf(char*,int,bool);
   const char *getPermissionString();
   bool isExe();
-  WCFiletype* checkFiletype( List *ftlist, bool skipcontent );
+  WCFiletype* checkFiletype( List *ftlist, bool skipcontent, class CondParser *condparser = NULL );
   bool match(char* pattern);
   bool checkAccess( int m );
 
@@ -143,6 +149,10 @@ public:
   loff_t dblocks() const;
   dev_t rdev() const;
   dev_t drdev() const;
+  
+  char *getContentStr( int pos, int len = 1 );
+  int getContentNum( int pos, int len = 1 );
+  void freeContentBuf();
 
   struct FE_stat {
     loff_t size;
@@ -172,6 +182,21 @@ public:
   bool use;
   
   bool reclistQueued;  // for filetype recognition in normalmode
+  
+  void freeOutputBuf();
+  const char *findOutput( const char *tcommand );
+  int findReturnvalue( const char *tcommand, int *return_value );
+  int findOutputAndRV( const char *tcommand, const char **return_output, int *return_value );
+  void addOutput( const char *tcommand, const char *toutput, int value = 0 );
+  
+  bool isReg() const;
+private:
+  struct {
+    char *content;
+    int size;
+  } contentBuf;
+  void readContentBuf( int len = 64 );
+  class StringBuf *outputBuf;
 };
 
 class Verzeichnis
@@ -179,6 +204,9 @@ class Verzeichnis
 public:
   Verzeichnis();
   ~Verzeichnis();
+  Verzeichnis( const Verzeichnis &other );
+  Verzeichnis &operator=( const Verzeichnis &other );
+
   ArrayList *getFiles();
   int readDir( const char *, bool dontWarnInvalid = false );
   void closeDir();
