@@ -1,6 +1,6 @@
 /* deleteop.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001 Ralf Hoffmann.
+ * Copyright (C) 2001-2004 Ralf Hoffmann.
  * You can contact me at: ralf.hoffmann@epost.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: deleteop.h,v 1.11 2003/06/04 23:26:30 ralf Exp $ */
+/* $Id: deleteop.h,v 1.13 2004/07/21 21:12:42 ralf Exp $ */
 
 #ifndef DELETEOP_H
 #define DELETEOP_H
@@ -38,9 +38,15 @@ class DeleteOp:public FunctionProto
 public:
   DeleteOp();
   virtual ~DeleteOp();
+  DeleteOp( const DeleteOp &other );
+  DeleteOp &operator=( const DeleteOp &other );
+
   virtual DeleteOp *duplicate() const;
   virtual bool isName(const char *);
   virtual const char *getName();
+#if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
+  using FunctionProto::run;
+#endif
   virtual int run(ActionMessage*);
   virtual const char *getDescription();
   virtual int configure();
@@ -63,6 +69,9 @@ class DeleteOpWin
 public:
   DeleteOpWin(AGUIX*);
   ~DeleteOpWin();
+  DeleteOpWin( const DeleteOpWin &other );
+  DeleteOpWin &operator=( const DeleteOpWin &other );
+
   int open();
   void close();
   // called once:
