@@ -1,6 +1,6 @@
 /* dirsizeop.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001 Ralf Hoffmann.
+ * Copyright (C) 2001-2004 Ralf Hoffmann.
  * You can contact me at: ralf.hoffmann@epost.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: dirsizeop.h,v 1.5 2003/05/04 00:53:11 ralf Exp $ */
+/* $Id: dirsizeop.h,v 1.7 2004/07/21 21:12:52 ralf Exp $ */
 
 #ifndef DIRSIZEOP_H
 #define DIRSIZEOP_H
@@ -33,9 +33,15 @@ class DirSizeOp:public FunctionProto
 public:
   DirSizeOp();
   virtual ~DirSizeOp();
+  DirSizeOp( const DirSizeOp &other );
+  DirSizeOp &operator=( const DirSizeOp &other );
+
   virtual DirSizeOp *duplicate() const;
   virtual bool isName(const char *);
   virtual const char *getName();
+#if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
+  using FunctionProto::run;
+#endif
   virtual int run(ActionMessage*);
   virtual const char *getDescription();
 protected:
