@@ -1,6 +1,6 @@
 /* dnd.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001 Ralf Hoffmann.
+ * Copyright (C) 2001-2004 Ralf Hoffmann.
  * You can contact me at: ralf.hoffmann@epost.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: dnd.h,v 1.5 2003/11/23 21:20:30 ralf Exp $ */
+/* $Id: dnd.h,v 1.6 2004/03/18 20:16:16 ralf Exp $ */
 
 #ifndef DND_H
 #define DND_H
@@ -37,6 +37,9 @@ public:
   DNDMsg(Worker *worker);
   DNDMsg(Worker *worker,AGDNDSTART s,AGDNDEND e);
   ~DNDMsg();
+  DNDMsg( const DNDMsg &other );
+  DNDMsg &operator=( const DNDMsg &other );
+
   FileEntry *getFE();
   const char *getDestDir();
   Lister *getDestLister();
