@@ -1,6 +1,6 @@
 /* enterpathop.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001 Ralf Hoffmann.
+ * Copyright (C) 2001-2004 Ralf Hoffmann.
  * You can contact me at: ralf.hoffmann@epost.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: enterpathop.h,v 1.5 2003/05/04 00:54:32 ralf Exp $ */
+/* $Id: enterpathop.h,v 1.7 2004/07/21 21:12:56 ralf Exp $ */
 
 #ifndef ENTERPATHOP_H
 #define ENTERPATHOP_H
@@ -36,9 +36,15 @@ class EnterPathOp:public FunctionProto
 public:
   EnterPathOp();
   virtual ~EnterPathOp();
+  EnterPathOp( const EnterPathOp &other );
+  EnterPathOp &operator=( const EnterPathOp &other );
+
   virtual EnterPathOp *duplicate() const;
   virtual bool isName(const char *);
   virtual const char *getName();
+#if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
+  using FunctionProto::run;
+#endif
   virtual int run(ActionMessage*);
   virtual bool save(Datei*);
   virtual const char *getDescription();
