@@ -1,6 +1,6 @@
 /* execlass.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2002 Ralf Hoffmann.
+ * Copyright (C) 2002-2004 Ralf Hoffmann.
  * You can contact me at: ralf.hoffmann@epost.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: execlass.cc,v 1.9 2002/12/15 02:11:17 ralf Exp $ */
+/* $Id: execlass.cc,v 1.11 2004/06/13 21:30:16 ralf Exp $ */
 
 #include "execlass.h"
 #include <stdarg.h>
@@ -28,6 +28,7 @@
 #include "wconfig.h"
 #include "worker.h"
 
+/* THREADSAFE */
 ExeClass::ExeClass( execlass_execute_t exetype, Worker *w )
 {
   worker = w;
@@ -77,6 +78,7 @@ ExeClass::~ExeClass()
    This way I get the same security as using exec but I can execute more
    then one command and run them in a terminal or capturing the output
  */
+/* THREADSAFE */
 void ExeClass::addCommand( const char *format, ... )
 {
   va_list va;
@@ -108,6 +110,8 @@ void ExeClass::addCommand( const char *format, ... )
   }
 }
 
+/* THREADSAFE if worker == NULL or worker THREADSAFE
+              and if wconfig THREADSAFE or type !=TERMINAL */
 void ExeClass::execute()
 {
   char *exestr = NULL;
@@ -140,20 +144,47 @@ void ExeClass::execute()
   if ( worker != NULL ) worker->unsetWaitCursor();
 }
 
+/* THREADSAFE if worker == NULL or worker THREADSAFE */
 char *ExeClass::getOutput()
 {
   return getOutput( NULL );
 }
 
+/* THREADSAFE if worker == NULL or worker THREADSAFE */
 char *ExeClass::getOutput( int *return_error )
+{
+  char *erg = NULL;
+  
+  if ( getOutputAndRV( &erg, NULL, return_error ) != 0 ) return NULL;
+  return erg;
+}
+
+/* THREADSAFE if worker == NULL or worker THREADSAFE */
+int ExeClass::getReturnCode()
+{
+  return getReturnCode( NULL );
+}
+
+/* THREADSAFE if worker == NULL or worker THREADSAFE */
+int ExeClass::getReturnCode( int *return_error )
+{
+  int erg;
+
+  if ( getOutputAndRV( NULL, &erg, return_error ) != 0 ) return -1;
+  return erg;
+}
+
+/* THREADSAFE if worker == NULL or worker THREADSAFE */
+int ExeClass::getOutputAndRV( char **return_output, int *return_value, int *return_error )
 {
   std::string exestr;
   Datei *d;
   char *erg = NULL;
+  int rerg = -1;
   
   /* only when type is normal because we want no user interaction */
-  if ( type != EXECUTE_NORMAL ) return NULL;
-  if ( fp == NULL ) return NULL;
+  if ( type != EXECUTE_NORMAL ) return 1;
+  if ( fp == NULL ) return 1;
   
   if ( worker != NULL ) worker->setWaitCursor();
 
@@ -165,7 +196,7 @@ char *ExeClass::getOutput( int *return_error )
   exestr += tmpoutput;
   exestr += " 2>";
   exestr += tmperror;
-  system( exestr.c_str() );
+  rerg = system( exestr.c_str() );
   d = new Datei();
   if ( d->open( tmpoutput, "r" ) == 0 ) {
     erg = d->getLine();
@@ -187,52 +218,13 @@ char *ExeClass::getOutput( int *return_error )
 
   if ( worker != NULL ) worker->unsetWaitCursor();
 
-  return erg;
-}
-
-int ExeClass::getReturnCode()
-{
-  return getReturnCode( NULL );
-}
-
-int ExeClass::getReturnCode( int *return_error )
-{
-  int erg;
-  std::string exestr;
+  if ( return_output != NULL ) *return_output = erg;
+  if ( return_value != NULL ) *return_value = rerg;
   
-  /* only when type is normal because we want no user interaction */
-  if ( type != EXECUTE_NORMAL ) return -1;
-  if ( fp == NULL ) return -1;
-  
-  if ( worker != NULL ) worker->setWaitCursor();
-
-  fclose( fp );
-  fp = NULL;
-
-  exestr = tmpfile;
-  exestr += " 2>";
-  exestr += tmperror;
-
-  erg = system( exestr.c_str() );
-
-  if ( Datei::fileExistsExt( tmperror ) == Datei::D_FE_FILE ) {
-    if ( Datei::fileSize( tmperror ) != 0 ) {
-      // filesize has to be 0 if anything was okay
-      lasterror = 2;
-    } else {
-      lasterror = 0;
-    }
-  } else {
-    // error file not found => assume something gone wrong
-    lasterror = 1;
-  }
-  if ( return_error != NULL ) *return_error = lasterror;
-
-  if ( worker != NULL ) worker->unsetWaitCursor();
-
-  return erg;
+  return 0;
 }
 
+/* THREADSAFE */
 void ExeClass::cdDir( const char *dir )
 {
   char *tstr;
@@ -243,6 +235,7 @@ void ExeClass::cdDir( const char *dir )
   }
 }
 
+/* THREADSAFE */
 int ExeClass::getLastError()
 {
   return lasterror;
@@ -252,8 +245,11 @@ int ExeClass::getLastError()
  * non-class functions *
  ***********************/
 
-/* create a argv vector from a string and return size of vector
+/*
+ * Worker_buildArgvList
+ * create a argv vector from a string and return size of vector
  * without last NULL element
+ * THREADSAFE
  */
 int Worker_buildArgvList( const char *str, char ***argvlist )
 {
@@ -326,6 +322,10 @@ int Worker_buildArgvList( const char *str, char ***argvlist )
   return size;
 }
 
+/*
+ * Worker_freeArgvList
+ * THREADSAFE
+ */
 void Worker_freeArgvList( char **argvlist )
 {
   int i;
@@ -347,6 +347,10 @@ typedef enum { WORKER_IS_NORMAL,
                WORKER_IS_OUTPUT_1,
                WORKER_IS_OUTPUT_2 } redirectmode_t;
 
+/*
+ * Worker_getRedirectMode
+ * THREADSAFE
+ */
 int Worker_getRedirectMode( const char *str1, redirectmode_t *return_mode, int *return_filedescr, int *return_offset )
 {
   redirectmode_t redirectmode;
@@ -515,6 +519,10 @@ int Worker_getRedirectMode( const char *str1, redirectmode_t *return_mode, int *
         } else 
 #endif
 
+/*
+ * Worker_secureCommandForShell
+ * THREADSAFE
+ */
 std::string Worker_secureCommandForShell( const char *str )
 {
   int i, n;
@@ -653,6 +661,10 @@ std::string Worker_secureCommandForShell( const char *str )
   if ( str[quotestart] != '{' ) i--; \
 }
 
+/*
+ * Worker_replaceEnv
+ * THREADSAFE
+ */
 char *Worker_replaceEnv( const char *str )
 {
   int quotemode = 0; /* 0 means no quote
