@@ -1,6 +1,6 @@
 /* filereq.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001 Ralf Hoffmann.
+ * Copyright (C) 2001-2004 Ralf Hoffmann.
  * You can contact me at: ralf.hoffmann@epost.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: filereq.h,v 1.8 2003/11/23 21:20:43 ralf Exp $ */
+/* $Id: filereq.h,v 1.9 2004/03/18 20:16:49 ralf Exp $ */
 
 #ifndef FILEREQ_H
 #define FILEREQ_H
@@ -37,6 +37,9 @@ class FileRequester
 public:
   FileRequester(AGUIX *parent);
   ~FileRequester();
+  FileRequester( const FileRequester &other );
+  FileRequester &operator=( const FileRequester &other );
+
   int request( const char *title, const char *dir, const char *oktext, const char *canceltext, const char *infotext);
   int request_entry( const char *title,
                      const char *dir,
