@@ -1,6 +1,6 @@
 /* fontreq.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001 Ralf Hoffmann.
+ * Copyright (C) 2001-2004 Ralf Hoffmann.
  * You can contact me at: ralf.hoffmann@epost.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: fontreq.h,v 1.6 2003/11/23 21:20:48 ralf Exp $ */
+/* $Id: fontreq.h,v 1.7 2004/03/18 20:16:57 ralf Exp $ */
 
 #ifndef FONTREQ_H
 #define FONTREQ_H
@@ -36,6 +36,9 @@ class FontRequester
 public:
   FontRequester(class AGUIX *parent);
   ~FontRequester();
+  FontRequester( const FontRequester &other );
+  FontRequester &operator=( const FontRequester &other );
+
   int request(char *xname,char**return_xname);
 
   struct request_fonts {
