@@ -1,6 +1,6 @@
 /* functionproto.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001 Ralf Hoffmann.
+ * Copyright (C) 2001-2004 Ralf Hoffmann.
  * You can contact me at: ralf.hoffmann@epost.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: functionproto.h,v 1.10 2003/05/04 00:56:12 ralf Exp $ */
+/* $Id: functionproto.h,v 1.11 2004/03/18 20:17:06 ralf Exp $ */
 
 #ifndef FUNCTIONPROTO_H
 #define FUNCTIONPROTO_H
@@ -37,6 +37,9 @@ class ActionMessage
 public:
   ActionMessage( Worker *);
   ~ActionMessage();
+  ActionMessage( const ActionMessage &other );
+  ActionMessage &operator=( const ActionMessage &other );
+
   WCGlobalFlags *flags;
   
   typedef enum {AM_MODE_NORMAL,
@@ -57,6 +60,9 @@ class FunctionProto
 public:
   FunctionProto();
   virtual ~FunctionProto();
+  FunctionProto( const FunctionProto &other );
+  FunctionProto &operator=( const FunctionProto &other );
+
   virtual int configure();
   virtual FunctionProto *duplicate() const;
   virtual bool isName(const char *);
