@@ -1,6 +1,6 @@
 /* informationmode.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001 Ralf Hoffmann.
+ * Copyright (C) 2001-2004 Ralf Hoffmann.
  * You can contact me at: ralf.hoffmann@epost.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: informationmode.h,v 1.8 2003/07/03 22:50:46 ralf Exp $ */
+/* $Id: informationmode.h,v 1.9 2004/03/18 20:17:31 ralf Exp $ */
 
 #ifndef INFORMATIONMODE_H
 #define INFORMATIONMODE_H
@@ -42,6 +42,9 @@ class InformationMode:public ListerMode
 public:
   InformationMode(Lister *);
   virtual ~InformationMode();
+  InformationMode( const InformationMode &other );
+  InformationMode &operator=( const InformationMode &other );
+
   virtual void messageHandler(AGMessage *);
   virtual void on();
   virtual void off();
