@@ -1,6 +1,6 @@
 /* lister.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001 Ralf Hoffmann.
+ * Copyright (C) 2001-2004 Ralf Hoffmann.
  * You can contact me at: ralf.hoffmann@epost.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: lister.h,v 1.11 2003/11/23 21:20:57 ralf Exp $ */
+/* $Id: lister.h,v 1.12 2004/03/18 20:17:41 ralf Exp $ */
 
 #ifndef LISTER_H
 #define LISTER_H
@@ -43,6 +43,9 @@ class Lister
 public:
   Lister(Worker*);
   ~Lister();
+  Lister( const Lister &other );
+  Lister &operator=( const Lister &other );
+
   void messageHandler(AGMessage *msg);
   AGUIX *getAGUIX();
   AWindow *getAWindow();
