@@ -1,6 +1,6 @@
 /* listermode.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001 Ralf Hoffmann.
+ * Copyright (C) 2001-2004 Ralf Hoffmann.
  * You can contact me at: ralf.hoffmann@epost.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: listermode.h,v 1.10 2003/11/23 21:21:02 ralf Exp $ */
+/* $Id: listermode.h,v 1.11 2004/03/18 20:17:48 ralf Exp $ */
 
 #ifndef LISTERMODE_H
 #define LISTERMODE_H
@@ -36,6 +36,9 @@ class ListerMode
 public:
   ListerMode(Lister *);
   virtual ~ListerMode();
+  ListerMode( const ListerMode &other );
+  ListerMode &operator=( const ListerMode &other );
+
   virtual void messageHandler(AGMessage *);
   virtual void on();
   virtual void off();
