@@ -1,6 +1,6 @@
 /* makedirop.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001 Ralf Hoffmann.
+ * Copyright (C) 2001-2004 Ralf Hoffmann.
  * You can contact me at: ralf.hoffmann@epost.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,27 +18,28 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: makedirop.h,v 1.4 2003/05/04 01:02:32 ralf Exp $ */
+/* $Id: makedirop.h,v 1.6 2004/07/21 21:13:05 ralf Exp $ */
 
 #ifndef MAKEDIROP_H
 #define MAKEDIROP_H
 
 #include "wdefines.h"
 #include "functionproto.h"
-//#include <aguix/awindow.h>
-//#include <aguix/text.h>
-//#include <aguix/solidbutton.h>
-//#include <aguix/button.h>
-//#include <aguix/cyclebutton.h>
 
 class MakeDirOp:public FunctionProto
 {
 public:
   MakeDirOp();
   virtual ~MakeDirOp();
+  MakeDirOp( const MakeDirOp &other );
+  MakeDirOp &operator=( const MakeDirOp &other );
+
   virtual MakeDirOp *duplicate() const;
   virtual bool isName(const char *);
   virtual const char *getName();
+#if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
+  using FunctionProto::run;
+#endif
   virtual int run(ActionMessage*);
   virtual const char *getDescription();
 protected:
