@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: normalmode.h,v 1.92 2004/01/20 22:19:01 ralf Exp $ */
+/* $Id: normalmode.h,v 1.94 2004/06/13 21:32:35 ralf Exp $ */
 
 #ifndef NORMALMODE_H
 #define NORMALMODE_H
@@ -35,6 +35,7 @@
 #include "datei.h"
 #include "copyop.h"
 #include "deleteop.h"
+#include "condparser.h"
 
 #ifdef WANT_THREADS
 #include <aguix/mutex.h>
@@ -48,6 +49,9 @@ class NM_Filter {
 public:
   NM_Filter();
   ~NM_Filter();
+  NM_Filter( const NM_Filter &other );
+  NM_Filter &operator=( const NM_Filter &other );
+
   void setPattern(const char*);
   char *getPattern();
   void setCheck(int);
@@ -65,6 +69,9 @@ class NMCacheEntry {
 public:
   NMCacheEntry();
   ~NMCacheEntry();
+  NMCacheEntry( const NMCacheEntry &other );
+  NMCacheEntry &operator=( const NMCacheEntry &other );
+
   void recalcStats();
   void subentry(FileEntry *fe);
   void next_checkfe();
@@ -128,6 +135,9 @@ class NM_externorder {
 public:
   NM_externorder();
   ~NM_externorder();
+  NM_externorder( const NM_externorder &other );
+  NM_externorder &operator=( const NM_externorder &other );
+
   bool separate_each_entry;
   bool recursive;
   bool inbackground;
@@ -200,6 +210,9 @@ public:
   NM_extern_fe(char *nfn);
   NM_extern_fe(char *nfn,FileEntry *fe, int row );
   ~NM_extern_fe();
+  NM_extern_fe( const NM_extern_fe &other );
+  NM_extern_fe &operator=( const NM_extern_fe &other );
+
   char *getFullname(bool noext);
   char *getName(bool noext);
   void setDirFinished(int);
@@ -219,6 +232,9 @@ class NM_CopyOp_Dir
 public:
   NM_CopyOp_Dir(const FileEntry *fe);
   ~NM_CopyOp_Dir();
+  NM_CopyOp_Dir( const NM_CopyOp_Dir &other );
+  NM_CopyOp_Dir &operator=( const NM_CopyOp_Dir &other );
+
   int createSubDirs(struct NM_copyorder*copyorder,unsigned long *gf,unsigned long *gd);
   int createSubDirs(struct NM_deleteorder*delorder,unsigned long *gf,unsigned long *gd);
   int createSubDirs();
@@ -246,6 +262,9 @@ class NMExtList
 public:
   NMExtList();
   ~NMExtList();
+  NMExtList( const NMExtList &other );
+  NMExtList &operator=( const NMExtList &other );
+
   int getSize();
   int getRealSize();
   void setTakeDirs( bool nv);
@@ -267,6 +286,9 @@ class NormalMode:public ListerMode
 public:
   NormalMode(Lister *);
   virtual ~NormalMode();
+  NormalMode( const NormalMode &other );
+  NormalMode &operator=( const NormalMode &other );
+
   virtual void messageHandler(AGMessage *);
   virtual void on();
   virtual void off();
@@ -577,6 +599,8 @@ protected:
 
     ft_rec_list();
     ~ft_rec_list();
+    ft_rec_list( const ft_rec_list &other );
+    ft_rec_list &operator=( const ft_rec_list &other );
 
     int slaveread_locked( const char **name, bool *dontCheckContent );
     bool elemAvail_locked();
@@ -618,6 +642,8 @@ protected:
     
     ft_recres_list();
     ~ft_recres_list();
+    ft_recres_list( const ft_recres_list &other );
+    ft_recres_list &operator=( const ft_recres_list &other );
 
     bool isEmpty_locked();
     int put_locked( ft_recres_list_t *elem );
@@ -672,6 +698,8 @@ protected:
   
   int busyFlag;
   time_t lastBusyFlagUpdate;
+  
+  CondParser condparser;
 };
 
 class NMFieldListViewDND:public FieldListViewDND
@@ -679,6 +707,9 @@ class NMFieldListViewDND:public FieldListViewDND
 public:
   NMFieldListViewDND(AGUIX*,int,int,int,int,int);
   virtual ~NMFieldListViewDND();
+  NMFieldListViewDND( const NMFieldListViewDND &other );
+  NMFieldListViewDND &operator=( const NMFieldListViewDND &other );
+
   void setSelectHandler(NormalMode*);
 protected:
   NormalMode *nm;
