@@ -1,6 +1,6 @@
 /* normalops.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001 Ralf Hoffmann.
+ * Copyright (C) 2001-2004 Ralf Hoffmann.
  * You can contact me at: ralf.hoffmann@epost.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: normalops.h,v 1.9 2003/11/23 21:21:08 ralf Exp $ */
+/* $Id: normalops.h,v 1.11 2004/07/21 21:13:12 ralf Exp $ */
 
 #ifndef NORMALOPS_H
 #define NORMALOPS_H
@@ -32,10 +32,16 @@ class ChangeListerSetOp:public FunctionProto
 public:
   ChangeListerSetOp();
   virtual ~ChangeListerSetOp();
+  ChangeListerSetOp( const ChangeListerSetOp &other );
+  ChangeListerSetOp &operator=( const ChangeListerSetOp &other );
+
   virtual ChangeListerSetOp *duplicate() const;
   virtual int configure();
   virtual bool isName(const char *);
   virtual const char *getName();
+#if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
+  using FunctionProto::run;
+#endif
   virtual int run(ActionMessage*);
   virtual const char *getDescription();
   virtual bool save(Datei *);
@@ -52,9 +58,15 @@ class SwitchListerOp:public FunctionProto
 public:
   SwitchListerOp();
   virtual ~SwitchListerOp();
+  SwitchListerOp( const SwitchListerOp &other );
+  SwitchListerOp &operator=( const SwitchListerOp &other );
+
   virtual SwitchListerOp *duplicate() const;
   virtual bool isName(const char *);
   virtual const char *getName();
+#if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
+  using FunctionProto::run;
+#endif
   virtual int run(ActionMessage*);
   virtual const char *getDescription();
 protected:
@@ -66,10 +78,16 @@ class FilterSelectOp:public FunctionProto
 public:
   FilterSelectOp();
   virtual ~FilterSelectOp();
+  FilterSelectOp( const FilterSelectOp &other );
+  FilterSelectOp &operator=( const FilterSelectOp &other );
+
   virtual FilterSelectOp *duplicate() const;
   virtual int configure();
   virtual bool isName(const char *);
   virtual const char *getName();
+#if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
+  using FunctionProto::run;
+#endif
   virtual int run(ActionMessage*);
   virtual const char *getDescription();
   virtual bool save(Datei *);
@@ -96,10 +114,16 @@ class FilterUnSelectOp:public FilterSelectOp
 public:
   FilterUnSelectOp();
   virtual ~FilterUnSelectOp();
+  FilterUnSelectOp( const FilterUnSelectOp &other );
+  FilterUnSelectOp &operator=( const FilterUnSelectOp &other );
+
   virtual FilterUnSelectOp *duplicate() const;
   virtual int configure();
   virtual bool isName(const char *);
   virtual const char *getName();
+#if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
+  using FunctionProto::run;
+#endif
   virtual int run(ActionMessage*);
   virtual const char *getDescription();
   
@@ -113,9 +137,15 @@ class Path2OSideOp:public FunctionProto
 public:
   Path2OSideOp();
   virtual ~Path2OSideOp();
+  Path2OSideOp( const Path2OSideOp &other );
+  Path2OSideOp &operator=( const Path2OSideOp &other );
+
   virtual Path2OSideOp *duplicate() const;
   virtual bool isName(const char *);
   virtual const char *getName();
+#if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
+  using FunctionProto::run;
+#endif
   virtual int run(ActionMessage*);
   virtual const char *getDescription();
 protected:
@@ -127,10 +157,16 @@ class QuitOp:public FunctionProto
 public:
   QuitOp();
   virtual ~QuitOp();
+  QuitOp( const QuitOp &other );
+  QuitOp &operator=( const QuitOp &other );
+
   virtual QuitOp *duplicate() const;
   virtual int configure();
   virtual bool isName(const char *);
   virtual const char *getName();
+#if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
+  using FunctionProto::run;
+#endif
   virtual int run(ActionMessage*);
   virtual const char *getDescription();
   virtual bool save(Datei *);
