@@ -1,6 +1,6 @@
 /* ownop.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001 Ralf Hoffmann.
+ * Copyright (C) 2001-2004 Ralf Hoffmann.
  * You can contact me at: ralf.hoffmann@epost.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: ownop.h,v 1.14 2003/06/04 21:53:24 ralf Exp $ */
+/* $Id: ownop.h,v 1.16 2004/07/21 21:13:16 ralf Exp $ */
 
 #ifndef OWNOP_H
 #define OWNOP_H
@@ -86,9 +86,15 @@ class OwnOp:public FunctionProto
 public:
   OwnOp();
   virtual ~OwnOp();
+  OwnOp( const OwnOp &other );
+  OwnOp &operator=( const OwnOp &other );
+
   virtual OwnOp *duplicate() const;
   virtual bool isName(const char *);
   virtual const char *getName();
+#if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
+  using FunctionProto::run;
+#endif
   virtual int run( WPUContext *, ActionMessage * );
   virtual bool save(Datei*);
   virtual const char *getDescription();
