@@ -1,6 +1,6 @@
 /* partspace.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001 Ralf Hoffmann.
+ * Copyright (C) 2001-2004 Ralf Hoffmann.
  * You can contact me at: ralf.hoffmann@epost.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: partspace.h,v 1.10 2003/11/23 21:21:13 ralf Exp $ */
+/* $Id: partspace.h,v 1.11 2004/03/18 20:19:48 ralf Exp $ */
 
 #ifndef PARTSPACE_H
 #define PARTSPACE_H
@@ -37,6 +37,9 @@ class PartSpace
 public:
   PartSpace();
   ~PartSpace();
+  PartSpace( const PartSpace &other );
+  PartSpace &operator=( const PartSpace &other );
+
   int readSpace( const char*name );
   
   loff_t getBlocksize();
@@ -89,6 +92,8 @@ protected:
 
     SpaceRequestList();
     ~SpaceRequestList();
+    SpaceRequestList( const SpaceRequestList &other );
+    SpaceRequestList &operator=( const SpaceRequestList &other );
 
     bool isEmpty_locked();
     int put_locked( space_request_list_t *elem );
