@@ -1,6 +1,6 @@
 /* reloadop.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001 Ralf Hoffmann.
+ * Copyright (C) 2001-2004 Ralf Hoffmann.
  * You can contact me at: ralf.hoffmann@epost.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: reloadop.h,v 1.7 2003/05/04 01:09:22 ralf Exp $ */
+/* $Id: reloadop.h,v 1.9 2004/07/21 21:13:21 ralf Exp $ */
 
 #ifndef RELOADOP_H
 #define RELOADOP_H
@@ -38,9 +38,15 @@ class ReloadOp:public FunctionProto
 public:
   ReloadOp();
   virtual ~ReloadOp();
+  ReloadOp( const ReloadOp &other );
+  ReloadOp &operator=( const ReloadOp &other );
+
   virtual ReloadOp *duplicate() const;
   virtual bool isName(const char *);
   virtual const char *getName();
+#if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
+  using FunctionProto::run;
+#endif
   virtual int run(ActionMessage*);
   virtual bool save(Datei*);
   virtual const char *getDescription();
