@@ -1,6 +1,6 @@
 /* renameop.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001 Ralf Hoffmann.
+ * Copyright (C) 2001-2004 Ralf Hoffmann.
  * You can contact me at: ralf.hoffmann@epost.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: renameop.h,v 1.6 2003/05/04 01:09:53 ralf Exp $ */
+/* $Id: renameop.h,v 1.8 2004/07/21 21:13:25 ralf Exp $ */
 
 #ifndef RENAMEOP_H
 #define RENAMEOP_H
@@ -31,9 +31,15 @@ class RenameOp:public FunctionProto
 public:
   RenameOp();
   virtual ~RenameOp();
+  RenameOp( const RenameOp &other );
+  RenameOp &operator=( const RenameOp &other );
+
   virtual RenameOp *duplicate() const;
   virtual bool isName(const char *);
   virtual const char *getName();
+#if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
+  using FunctionProto::run;
+#endif
   virtual int run(ActionMessage*);
   virtual const char *getDescription();
 protected:
