@@ -1,6 +1,6 @@
 /* scrolllisterop.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001 Ralf Hoffmann.
+ * Copyright (C) 2001-2004 Ralf Hoffmann.
  * You can contact me at: ralf.hoffmann@epost.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: scrolllisterop.h,v 1.5 2003/05/04 01:13:00 ralf Exp $ */
+/* $Id: scrolllisterop.h,v 1.7 2004/07/21 21:13:36 ralf Exp $ */
 
 #ifndef SCROLLLISTEROP_H
 #define SCROLLLISTEROP_H
@@ -36,9 +36,15 @@ class ScrollListerOp:public FunctionProto
 public:
   ScrollListerOp();
   virtual ~ScrollListerOp();
+  ScrollListerOp( const ScrollListerOp &other );
+  ScrollListerOp &operator=( const ScrollListerOp &other );
+
   virtual ScrollListerOp *duplicate() const;
   virtual bool isName(const char *);
   virtual const char *getName();
+#if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
+  using FunctionProto::run;
+#endif
   virtual int run(ActionMessage*);
   virtual bool save(Datei*);
   virtual const char *getDescription();
