@@ -1,6 +1,6 @@
 /* searchentryop.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001 Ralf Hoffmann.
+ * Copyright (C) 2001-2004 Ralf Hoffmann.
  * You can contact me at: ralf.hoffmann@epost.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: searchentryop.h,v 1.5 2003/10/16 21:11:18 ralf Exp $ */
+/* $Id: searchentryop.h,v 1.7 2004/07/21 21:13:42 ralf Exp $ */
 
 #ifndef SEARCHENTRYOP_H
 #define SEARCHENTRYOP_H
@@ -31,9 +31,15 @@ class SearchEntryOp:public FunctionProto
 public:
   SearchEntryOp();
   virtual ~SearchEntryOp();
+  SearchEntryOp( const SearchEntryOp &other );
+  SearchEntryOp &operator=( const SearchEntryOp &other );
+
   virtual SearchEntryOp *duplicate() const;
   virtual bool isName(const char *);
   virtual const char *getName();
+#if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
+  using FunctionProto::run;
+#endif
   virtual int run(ActionMessage*);
   virtual const char *getDescription();
   virtual bool save(Datei*);
