@@ -1,6 +1,6 @@
 /* setsortmodeop.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001 Ralf Hoffmann.
+ * Copyright (C) 2001-2004 Ralf Hoffmann.
  * You can contact me at: ralf.hoffmann@epost.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: setsortmodeop.h,v 1.5 2003/11/23 21:21:26 ralf Exp $ */
+/* $Id: setsortmodeop.h,v 1.7 2004/07/21 21:13:52 ralf Exp $ */
 
 #ifndef SETSORTMODEOP_H
 #define SETSORTMODEOP_H
@@ -32,9 +32,15 @@ class SetSortmodeOp:public FunctionProto
 public:
   SetSortmodeOp();
   virtual ~SetSortmodeOp();
+  SetSortmodeOp( const SetSortmodeOp &other );
+  SetSortmodeOp &operator=( const SetSortmodeOp &other );
+
   virtual SetSortmodeOp *duplicate() const;
   virtual bool isName(const char *);
   virtual const char *getName();
+#if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
+  using FunctionProto::run;
+#endif
   virtual int run(ActionMessage*);
   virtual bool save(Datei*);
   virtual const char *getDescription();
