@@ -1,6 +1,6 @@
 /* shortkeyfromlistop.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001 Ralf Hoffmann.
+ * Copyright (C) 2001-2004 Ralf Hoffmann.
  * You can contact me at: ralf.hoffmann@epost.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: shortkeyfromlistop.h,v 1.2 2003/05/04 01:16:38 ralf Exp $ */
+/* $Id: shortkeyfromlistop.h,v 1.4 2004/07/21 21:13:56 ralf Exp $ */
 
 #ifndef SHORTKEYFROMLIST_H
 #define SHORTKEYFROMLIST_H
@@ -31,9 +31,15 @@ class ShortkeyFromListOp:public FunctionProto
 public:
   ShortkeyFromListOp();
   virtual ~ShortkeyFromListOp();
+  ShortkeyFromListOp( const ShortkeyFromListOp &other );
+  ShortkeyFromListOp &operator=( const ShortkeyFromListOp &other );
+
   virtual ShortkeyFromListOp *duplicate() const;
   virtual bool isName(const char *);
   virtual const char *getName();
+#if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
+  using FunctionProto::run;
+#endif
   virtual int run(ActionMessage*);
   virtual const char *getDescription();
 protected:
