@@ -1,6 +1,6 @@
 /* showdircacheop.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2002 Ralf Hoffmann.
+ * Copyright (C) 2002-2004 Ralf Hoffmann.
  * You can contact me at: ralf.hoffmann@epost.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: showdircacheop.h,v 1.2 2003/05/04 01:16:56 ralf Exp $ */
+/* $Id: showdircacheop.h,v 1.4 2004/07/21 21:14:00 ralf Exp $ */
 
 #ifndef SHOWDIRCACHEOP_H
 #define SHOWDIRCACHEOP_H
@@ -33,9 +33,15 @@ class ShowDirCacheOp:public FunctionProto
 public:
   ShowDirCacheOp();
   virtual ~ShowDirCacheOp();
+  ShowDirCacheOp( const ShowDirCacheOp &other );
+  ShowDirCacheOp &operator=( const ShowDirCacheOp &other );
+
   virtual ShowDirCacheOp *duplicate() const;
   virtual bool isName(const char *);
   virtual const char *getName();
+#if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
+  using FunctionProto::run;
+#endif
   virtual int run(ActionMessage*);
   virtual const char *getDescription();
 
