@@ -1,6 +1,6 @@
 /* showimagemode.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001 Ralf Hoffmann.
+ * Copyright (C) 2001-2004 Ralf Hoffmann.
  * You can contact me at: ralf.hoffmann@epost.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: showimagemode.h,v 1.9 2003/08/24 20:59:41 ralf Exp $ */
+/* $Id: showimagemode.h,v 1.10 2004/03/18 20:21:49 ralf Exp $ */
 
 #ifndef SHOWIMAGEMODE_H
 #define SHOWIMAGEMODE_H
@@ -41,6 +41,9 @@ class ShowImageMode:public ListerMode
 public:
   ShowImageMode(Lister *);
   virtual ~ShowImageMode();
+  ShowImageMode( const ShowImageMode &other );
+  ShowImageMode &operator=( const ShowImageMode &other );
+
   virtual void messageHandler(AGMessage *);
   virtual void on();
   virtual void off();
