@@ -1,6 +1,6 @@
 /* simddop.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001 Ralf Hoffmann.
+ * Copyright (C) 2001-2004 Ralf Hoffmann.
  * You can contact me at: ralf.hoffmann@epost.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: simddop.h,v 1.5 2003/05/04 01:17:59 ralf Exp $ */
+/* $Id: simddop.h,v 1.7 2004/07/21 21:14:04 ralf Exp $ */
 
 #ifndef SIMDDEOP_H
 #define SIMDDOP_H
@@ -31,9 +31,15 @@ class SimDDOp:public FunctionProto
 public:
   SimDDOp();
   virtual ~SimDDOp();
+  SimDDOp( const SimDDOp &other );
+  SimDDOp &operator=( const SimDDOp &other );
+
   virtual SimDDOp *duplicate() const;
   virtual bool isName(const char *);
   virtual const char *getName();
+#if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
+  using FunctionProto::run;
+#endif
   virtual int run(ActionMessage*);
   virtual const char *getDescription();
 protected:
