@@ -1,6 +1,6 @@
 /* startprogop.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001 Ralf Hoffmann.
+ * Copyright (C) 2001-2004 Ralf Hoffmann.
  * You can contact me at: ralf.hoffmann@epost.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: startprogop.h,v 1.7 2003/05/04 01:18:49 ralf Exp $ */
+/* $Id: startprogop.h,v 1.9 2004/07/21 21:14:08 ralf Exp $ */
 
 #ifndef STARTPROGOP_H
 #define STARTPROGOP_H
@@ -37,9 +37,15 @@ class StartProgOp:public FunctionProto
 public:
   StartProgOp();
   virtual ~StartProgOp();
+  StartProgOp( const StartProgOp &other );
+  StartProgOp &operator=( const StartProgOp &other );
+
   virtual StartProgOp *duplicate() const;
   virtual bool isName(const char *);
   virtual const char *getName();
+#if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
+  using FunctionProto::run;
+#endif
   virtual int run(ActionMessage*);
   virtual bool save(Datei*);
   virtual const char *getDescription();
