@@ -1,6 +1,6 @@
 /* togglelistermodeop.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001 Ralf Hoffmann.
+ * Copyright (C) 2001-2004 Ralf Hoffmann.
  * You can contact me at: ralf.hoffmann@epost.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: togglelistermodeop.h,v 1.6 2003/05/04 01:20:09 ralf Exp $ */
+/* $Id: togglelistermodeop.h,v 1.8 2004/07/21 21:14:14 ralf Exp $ */
 
 #ifndef TOGGLELISTRERMODEOP_H
 #define TOGGLELISTRERMODEOP_H
@@ -39,9 +39,15 @@ class ToggleListermodeOp:public FunctionProto
 public:
   ToggleListermodeOp();
   virtual ~ToggleListermodeOp();
+  ToggleListermodeOp( const ToggleListermodeOp &other );
+  ToggleListermodeOp &operator=( const ToggleListermodeOp &other );
+
   virtual ToggleListermodeOp *duplicate() const;
   virtual bool isName(const char *);
   virtual const char *getName();
+#if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
+  using FunctionProto::run;
+#endif
   virtual int run(ActionMessage*);
   virtual bool save(Datei*);
   virtual const char *getDescription();
