@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: wconfig.h,v 1.47 2004/03/07 22:35:46 ralf Exp $ */
+/* $Id: wconfig.h,v 1.49 2004/06/13 21:36:11 ralf Exp $ */
 
 #ifndef WCONFIG_H
 #define WCONFIG_H
@@ -51,7 +51,11 @@ class WC_Color
 public:
   WC_Color();
   WC_Color( int r, int g, int b);
+  WC_Color( const WC_Color &other );
+  WC_Color &operator=( const WC_Color &other );
+
   WC_Color *duplicate();
+
   int getRed() const;
   int getGreen() const;
   int getBlue() const;
@@ -67,6 +71,9 @@ class WCShortkey
 public:
   WCShortkey();
   ~WCShortkey();
+  WCShortkey( const WCShortkey &other );
+  WCShortkey &operator=( const WCShortkey &other );
+
   WCShortkey *duplicate();
   void setShortkey(KeySym);
   void setMod(unsigned int);
@@ -84,6 +91,9 @@ class WCDoubleShortkey
 public:
   WCDoubleShortkey();
   ~WCDoubleShortkey();
+  WCDoubleShortkey( const WCDoubleShortkey &other );
+  WCDoubleShortkey &operator=( const WCDoubleShortkey &other );
+
   WCDoubleShortkey *duplicate() const;
   void setKeySym( KeySym k, int pos );
   KeySym getKeySym( int pos );
@@ -111,6 +121,9 @@ public:
 
   WConfig(Worker *);
   ~WConfig();
+  WConfig( const WConfig &other );
+  WConfig &operator=( const WConfig &other );
+
   WConfig *duplicate();
   void setLang( const char* );
   void setTerminalBin(const char*);
@@ -460,7 +473,9 @@ protected:
   
   void removeAllKeys();
   WCKey();
-  ~WCKey();
+  virtual ~WCKey();
+  WCKey( const WCKey &other );
+  WCKey &operator=( const WCKey &other );
 };
 
 class WCPath:public WCKey
@@ -468,6 +483,9 @@ class WCPath:public WCKey
 public:
   WCPath();
   ~WCPath();
+  WCPath( const WCPath &other );
+  WCPath &operator=( const WCPath &other );
+
   WCPath *duplicate();
   void setName(const char*);
   void setFG(int);
@@ -493,6 +511,9 @@ class WCGlobalFlags
 public:
   WCGlobalFlags();
   ~WCGlobalFlags();
+  WCGlobalFlags( const WCGlobalFlags &other );
+  WCGlobalFlags &operator=( const WCGlobalFlags &other );
+
   WCGlobalFlags *duplicate();
   unsigned long getFlags();
   void setFlags(unsigned long);
@@ -509,6 +530,9 @@ class WCFiletype
 public:
   WCFiletype();
   ~WCFiletype();
+  WCFiletype( const WCFiletype &other );
+  WCFiletype &operator=( const WCFiletype &other );
+
   WCFiletype *duplicate();
   void setName(const char*);
   void setPattern(const char*);
@@ -567,6 +591,11 @@ public:
   
   void clearFiledesc();
   void setFiledesc( int pos, short v );
+
+  void setExtCond( const char* );
+  void setUseExtCond( bool );
+  const char *getExtCond() const;
+  bool getUseExtCond() const;
 protected:
   char *name;
   char *pattern;
@@ -599,6 +628,9 @@ protected:
   bool patternIgnoreCase;
   bool patternUseRegExp;
   bool patternUseFullname;
+  
+  char *extCond;
+  bool useExtCond;
 #ifdef HAVE_REGEX
   regex_t patternReg;
   bool patternRegCompiled;
@@ -612,6 +644,9 @@ class WCHotkey:public WCKey
 public:
   WCHotkey();
   ~WCHotkey();
+  WCHotkey( const WCHotkey &other );
+  WCHotkey &operator=( const WCHotkey &other );
+
   WCHotkey *duplicate();
   void setName(const char*);
   char *getName();
@@ -635,6 +670,9 @@ class WCButton:public WCKey
 public:
   WCButton();
   ~WCButton();
+  WCButton( const WCButton &other );
+  WCButton &operator=( const WCButton &other );
+
   WCButton *duplicate();
   void setText(const char*);
   void setFG(int);
