@@ -1,6 +1,6 @@
 /* wdefines.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001 Ralf Hoffmann.
+ * Copyright (C) 2001-2004 Ralf Hoffmann.
  * You can contact me at: ralf.hoffmann@epost.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: wdefines.h,v 1.33 2003/11/26 19:22:25 ralf Exp $ */
+/* $Id: wdefines.h,v 1.36 2004/07/05 20:12:59 ralf Exp $ */
 
 #ifndef WDEFINES_H
 #define WDEFINES_H
@@ -54,6 +54,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <strings.h>
 #include <math.h>
 #include <time.h>
 #include <sys/time.h>
@@ -120,4 +121,12 @@
 #define w_max(a,b) (((a)>(b))?(a):(b))
 #define w_min(a,b) (((a)<(b))?(a):(b))
 
+#if ( ! defined S_ISSOCK  ) && defined S_IFSOCK
+#  define S_ISSOCK(mode) ( ( (mode) & S_IFMT ) == S_IFSOCK )
+#endif
+
+#if ( ! defined S_ISLNK  ) && defined S_IFLNK
+#  define S_ISLNK(mode) ( ( (mode) & S_IFMT ) == S_IFLNK )
+#endif
+
 #endif
