@@ -1,6 +1,6 @@
 /* worker.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001,2004 Ralf Hoffmann.
+ * Copyright (C) 2001-2004 Ralf Hoffmann.
  * You can contact me at: ralf.hoffmann@epost.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: worker.h,v 1.37 2004/02/26 22:54:29 ralf Exp $ */
+/* $Id: worker.h,v 1.38 2004/03/18 20:23:44 ralf Exp $ */
 
 #ifndef WORKER_H
 #define WORKER_H
@@ -46,6 +46,9 @@ class Worker
 public:
   Worker(int argc,char **argv);
   ~Worker();
+  Worker( const Worker &other );
+  Worker &operator=( const Worker &other );
+
   void run();
   static AGUIX *getAGUIX();
   static int getMaxModeNr();
