@@ -1,6 +1,6 @@
 /* worker_locale.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001 Ralf Hoffmann.
+ * Copyright (C) 2001-2004 Ralf Hoffmann.
  * You can contact me at: ralf.hoffmann@epost.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,13 +18,13 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: worker_locale.cc,v 1.149 2004/03/07 22:38:24 ralf Exp $ */
+/* $Id: worker_locale.cc,v 1.154 2004/07/04 20:05:25 ralf Exp $ */
 
 #include "worker_locale.h"
 #include "wconfig.h"
 #include "worker.h"
 
-#define CATENTRY 573
+#define CATENTRY 595
 #define CATCOMENTRY 46
 #define CATFLAGENTRY 54
 
@@ -538,7 +538,7 @@ void WorkerLocale::initBuiltinLang()
   catalog[480]=dupstring( "Cannot push the output of the following command because it writes something to stderr|and I take this as an error:|%s|Aborting..." );
   catalog[481]=dupstring( "Choose flag:|The flags beginning at {Rs} are only allowed|inside \"\" or in ?{}/${}!" );
   catalog[482]=dupstring( "You can choose flags with the requester by clicking at \"F\".|You can use parentheses if necessary, && means both sides have to be true, \\|\\| one of both.|\
-use <, <=, ==, >=, >, != as usual; when both sides are strings (\"\" or !{}) they are compared as strings, otherwise with the|\
+use <, <=, ==, >=, >, != as usual; when both sides are strings (\"\" or ${}) they are compared as strings, otherwise with the|\
 numerical value. So ( \"5\" > \"06\" ) is true while ( 5 > \"06\" ) is false!" );
   catalog[483]=dupstring( "Help" );
   catalog[484]=dupstring( "if-debug: Result of %s is %d" );
@@ -641,6 +641,43 @@ The default value here is the active entry and it's already correctly protected!
   catalog[570]=dupstring( "Match full filename" );
   catalog[571]=dupstring( "Swap next" );
   catalog[572]=dupstring( "Swap prev" );
+  catalog[573]=dupstring( "extended test:" );
+  catalog[574]=dupstring( "use extended test" );
+  catalog[575]=dupstring( "Pattern" );
+  catalog[576]=dupstring( "Extended Test" );
+  catalog[577]=dupstring( "Without using regular expressions, you can use the common shell \
+wildcards:| * for matching any string| ? for matching a single character|\
+ [...] for matching a character class|See the shell manual for more information.||\
+You can also use basic regular expressions, some examples follow:| .* for matching any string|\
+ \\+ matches one or more occurences| \\? matches zero or one occurence|\
+ ^ matches the beginning of the line| $ matches the end| \\( and \\) can be used for sub\
+expressions| \\\\\\| matches one of the subexpressions|For more information see the regular \
+expression manual (man 7 regex)" );
+  catalog[578]=dupstring( "Choose flag:" );
+  catalog[579]=dupstring( "true if entry is a regular file" );
+  catalog[580]=dupstring( "true if entry is a socket" );
+  catalog[581]=dupstring( "true if entry is a FIFO (pipe)" );
+  catalog[582]=dupstring( "true if entry is a symlink" );
+  catalog[583]=dupstring( "filesize" );
+  catalog[584]=dupstring( "permission (numerical) bitwise-and'd with mask" );
+  catalog[585]=dupstring( "lowers string" );
+  catalog[586]=dupstring( "uppers string" );
+  catalog[587]=dupstring( "replaces with file content from start to optional end offset" );
+  catalog[588]=dupstring( "replaces with file content read as number from start to optional \
+end offset" );
+  catalog[589]=dupstring( "filename" );
+  catalog[590]=dupstring( "full filename" );
+  catalog[591]=dupstring( "filename (only valid inside strings)" );
+  catalog[592]=dupstring( "full filename (only valid inside strings)" );
+  catalog[593]=dupstring( "You can choose flags with the requester by clicking at the \"F\". Start \
+the flag identifier|with a \"-\" if you don't want to quote the string (e.g. {-f}). The functions \
+\"contentStr\"|and \"contentNum\" can be called without a second argument which will \
+use only one character.|You \
+can use parentheses if necessary, && means both sides have to be true, \\|\\| one of both.|\
+use <, <=, ==, >=, >, != as usual and ~= for string comparison using regular|expressions; \
+when both sides are strings (\"\" or ${}) they are compared as strings,|otherwise with the \
+numerical value. So ( \"5\" > \"06\" ) is true while ( 5 > \"06\" ) is false!" );
+  catalog[594]=dupstring( "Move file %s" );
 
 //  catalog[]=dupstring( "" );
   
